Class: CloudmersiveConvertApiClient::ConvertDocumentApi
- Inherits:
-
Object
- Object
- CloudmersiveConvertApiClient::ConvertDocumentApi
- Defined in:
- lib/cloudmersive-convert-api-client/api/convert_document_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#convert_document_autodetect_get_info(input_file, opts = {}) ⇒ AutodetectGetInfoResult
Get document type information Auto-detects a document's type information; does not require file extension.
-
#convert_document_autodetect_get_info_with_http_info(input_file, opts = {}) ⇒ Array<(AutodetectGetInfoResult, Fixnum, Hash)>
Get document type information Auto-detects a document's type information; does not require file extension.
-
#convert_document_autodetect_to_pdf(input_file, opts = {}) ⇒ String
Convert Document to PDF Automatically detect file type and convert it to PDF.
-
#convert_document_autodetect_to_pdf_with_http_info(input_file, opts = {}) ⇒ Array<(String, Fixnum, Hash)>
Convert Document to PDF Automatically detect file type and convert it to PDF.
-
#convert_document_autodetect_to_png_array(input_file, opts = {}) ⇒ AutodetectToPngResult
Convert Document to PNG array Automatically detect file type and convert it to an array of PNG images.
-
#convert_document_autodetect_to_png_array_with_http_info(input_file, opts = {}) ⇒ Array<(AutodetectToPngResult, Fixnum, Hash)>
Convert Document to PNG array Automatically detect file type and convert it to an array of PNG images.
-
#convert_document_csv_to_xlsx(input_file, opts = {}) ⇒ String
CSV to Excel XLSX Convert CSV file to Office Excel XLSX Workbooks file format.
-
#convert_document_csv_to_xlsx_with_http_info(input_file, opts = {}) ⇒ Array<(String, Fixnum, Hash)>
CSV to Excel XLSX Convert CSV file to Office Excel XLSX Workbooks file format.
-
#convert_document_doc_to_docx(input_file, opts = {}) ⇒ String
Word DOC (97-03) to DOCX Convert/upgrade Office Word (97-2003 Format) Documents (doc) to the modern DOCX format.
-
#convert_document_doc_to_docx_with_http_info(input_file, opts = {}) ⇒ Array<(String, Fixnum, Hash)>
Word DOC (97-03) to DOCX Convert/upgrade Office Word (97-2003 Format) Documents (doc) to the modern DOCX format.
-
#convert_document_doc_to_pdf(input_file, opts = {}) ⇒ String
Word DOC (97-03) to PDF Convert Office Word (97-2003 Format) Documents (doc) to standard PDF.
-
#convert_document_doc_to_pdf_with_http_info(input_file, opts = {}) ⇒ Array<(String, Fixnum, Hash)>
Word DOC (97-03) to PDF Convert Office Word (97-2003 Format) Documents (doc) to standard PDF.
-
#convert_document_docx_to_pdf(input_file, opts = {}) ⇒ String
Word DOCX to PDF Convert Office Word Documents (docx) to standard PDF.
-
#convert_document_docx_to_pdf_with_http_info(input_file, opts = {}) ⇒ Array<(String, Fixnum, Hash)>
Word DOCX to PDF Convert Office Word Documents (docx) to standard PDF.
-
#convert_document_html_to_pdf(input_file, opts = {}) ⇒ String
HTML to PDF Convert standard HTML, with full support for CSS, JavaScript, Images, and other complex behavior to PDF.
-
#convert_document_html_to_pdf_with_http_info(input_file, opts = {}) ⇒ Array<(String, Fixnum, Hash)>
HTML to PDF Convert standard HTML, with full support for CSS, JavaScript, Images, and other complex behavior to PDF.
-
#convert_document_html_to_png(input_file, opts = {}) ⇒ PdfToPngResult
HTML to PNG array Convert standard HTML, with full support for CSS, JavaScript, Images, and other complex behavior to an array of PNG images, one for each page.
-
#convert_document_html_to_png_with_http_info(input_file, opts = {}) ⇒ Array<(PdfToPngResult, Fixnum, Hash)>
HTML to PNG array Convert standard HTML, with full support for CSS, JavaScript, Images, and other complex behavior to an array of PNG images, one for each page.
-
#convert_document_pdf_to_docx(input_file, opts = {}) ⇒ String
PDF to Word DOCX Convert standard PDF to Office Word Documents (docx).
-
#convert_document_pdf_to_docx_with_http_info(input_file, opts = {}) ⇒ Array<(String, Fixnum, Hash)>
PDF to Word DOCX Convert standard PDF to Office Word Documents (docx).
-
#convert_document_pdf_to_png_array(input_file, opts = {}) ⇒ PdfToPngResult
PDF to PNG Array Convert PDF document to PNG array, one image per page.
-
#convert_document_pdf_to_png_array_with_http_info(input_file, opts = {}) ⇒ Array<(PdfToPngResult, Fixnum, Hash)>
PDF to PNG Array Convert PDF document to PNG array, one image per page.
-
#convert_document_pdf_to_pptx(input_file, opts = {}) ⇒ String
PDF to PowerPoint PPTX Convert standard PDF to Office PowerPoint Presentation (pptx).
-
#convert_document_pdf_to_pptx_with_http_info(input_file, opts = {}) ⇒ Array<(String, Fixnum, Hash)>
PDF to PowerPoint PPTX Convert standard PDF to Office PowerPoint Presentation (pptx).
-
#convert_document_ppt_to_pdf(input_file, opts = {}) ⇒ String
PowerPoint PPT (97-03) to PDF Convert Office PowerPoint (97-2003) Documents (ppt) to standard PDF.
-
#convert_document_ppt_to_pdf_with_http_info(input_file, opts = {}) ⇒ Array<(String, Fixnum, Hash)>
PowerPoint PPT (97-03) to PDF Convert Office PowerPoint (97-2003) Documents (ppt) to standard PDF.
-
#convert_document_ppt_to_pptx(input_file, opts = {}) ⇒ String
PowerPoint PPT (97-03) to PPTX Convert/upgrade Office PowerPoint (97-2003) Documents (ppt) to modern PPTX.
-
#convert_document_ppt_to_pptx_with_http_info(input_file, opts = {}) ⇒ Array<(String, Fixnum, Hash)>
PowerPoint PPT (97-03) to PPTX Convert/upgrade Office PowerPoint (97-2003) Documents (ppt) to modern PPTX.
-
#convert_document_pptx_to_pdf(input_file, opts = {}) ⇒ String
PowerPoint PPTX to PDF Convert Office PowerPoint Documents (pptx) to standard PDF.
-
#convert_document_pptx_to_pdf_with_http_info(input_file, opts = {}) ⇒ Array<(String, Fixnum, Hash)>
PowerPoint PPTX to PDF Convert Office PowerPoint Documents (pptx) to standard PDF.
-
#convert_document_xls_to_pdf(input_file, opts = {}) ⇒ String
Excel XLS (97-03) to PDF Convert Office Excel (97-2003) Workbooks (xls) to standard PDF.
-
#convert_document_xls_to_pdf_with_http_info(input_file, opts = {}) ⇒ Array<(String, Fixnum, Hash)>
Excel XLS (97-03) to PDF Convert Office Excel (97-2003) Workbooks (xls) to standard PDF.
-
#convert_document_xls_to_xlsx(input_file, opts = {}) ⇒ String
Excel XLS (97-03) to XLSX Convert/upgrade Office Excel (97-2003) Workbooks (xls) to modern XLSX format.
-
#convert_document_xls_to_xlsx_with_http_info(input_file, opts = {}) ⇒ Array<(String, Fixnum, Hash)>
Excel XLS (97-03) to XLSX Convert/upgrade Office Excel (97-2003) Workbooks (xls) to modern XLSX format.
-
#convert_document_xlsx_to_csv(input_file, opts = {}) ⇒ String
Excel XLSX to CSV Convert Office Excel Workbooks (xlsx) to standard Comma-Separated Values (CSV) format.
-
#convert_document_xlsx_to_csv_with_http_info(input_file, opts = {}) ⇒ Array<(String, Fixnum, Hash)>
Excel XLSX to CSV Convert Office Excel Workbooks (xlsx) to standard Comma-Separated Values (CSV) format.
-
#convert_document_xlsx_to_pdf(input_file, opts = {}) ⇒ String
Excel XLSX to PDF Convert Office Excel Workbooks (xlsx) to standard PDF.
-
#convert_document_xlsx_to_pdf_with_http_info(input_file, opts = {}) ⇒ Array<(String, Fixnum, Hash)>
Excel XLSX to PDF Convert Office Excel Workbooks (xlsx) to standard PDF.
-
#initialize(api_client = ApiClient.default) ⇒ ConvertDocumentApi
constructor
A new instance of ConvertDocumentApi.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ ConvertDocumentApi
19 20 21 |
# File 'lib/cloudmersive-convert-api-client/api/convert_document_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/cloudmersive-convert-api-client/api/convert_document_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#convert_document_autodetect_get_info(input_file, opts = {}) ⇒ AutodetectGetInfoResult
Get document type information Auto-detects a document's type information; does not require file extension. Analyzes file contents to confirm file type. Even if no file extension is present, the auto-detect system will reliably analyze the contents of the file and identify its file type. Supports over 100 image file formats, Office document file formats, PDF, and more.
28 29 30 31 |
# File 'lib/cloudmersive-convert-api-client/api/convert_document_api.rb', line 28 def convert_document_autodetect_get_info(input_file, opts = {}) data, _status_code, _headers = convert_document_autodetect_get_info_with_http_info(input_file, opts) return data end |
#convert_document_autodetect_get_info_with_http_info(input_file, opts = {}) ⇒ Array<(AutodetectGetInfoResult, Fixnum, Hash)>
Get document type information Auto-detects a document's type information; does not require file extension. Analyzes file contents to confirm file type. Even if no file extension is present, the auto-detect system will reliably analyze the contents of the file and identify its file type. Supports over 100 image file formats, Office document file formats, PDF, and more.
38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/cloudmersive-convert-api-client/api/convert_document_api.rb', line 38 def convert_document_autodetect_get_info_with_http_info(input_file, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: ConvertDocumentApi.convert_document_autodetect_get_info ..." end # verify the required parameter 'input_file' is set if @api_client.config.client_side_validation && input_file.nil? fail ArgumentError, "Missing the required parameter 'input_file' when calling ConvertDocumentApi.convert_document_autodetect_get_info" end # resource path local_var_path = "/convert/autodetect/get-info" # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/octet-stream']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['multipart/form-data']) # form parameters form_params = {} form_params["inputFile"] = input_file # http body (model) post_body = nil auth_names = ['Apikey'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'AutodetectGetInfoResult') if @api_client.config.debugging @api_client.config.logger.debug "API called: ConvertDocumentApi#convert_document_autodetect_get_info\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#convert_document_autodetect_to_pdf(input_file, opts = {}) ⇒ String
Convert Document to PDF Automatically detect file type and convert it to PDF. Supports all of the major Office document file formats including Word (DOCX, DOC), Excel (XLSX, XLS), PowerPoint (PPTX, PPT), over 100 image formats, HTML files, and even multi-page TIFF files.
84 85 86 87 |
# File 'lib/cloudmersive-convert-api-client/api/convert_document_api.rb', line 84 def convert_document_autodetect_to_pdf(input_file, opts = {}) data, _status_code, _headers = convert_document_autodetect_to_pdf_with_http_info(input_file, opts) return data end |
#convert_document_autodetect_to_pdf_with_http_info(input_file, opts = {}) ⇒ Array<(String, Fixnum, Hash)>
Convert Document to PDF Automatically detect file type and convert it to PDF. Supports all of the major Office document file formats including Word (DOCX, DOC), Excel (XLSX, XLS), PowerPoint (PPTX, PPT), over 100 image formats, HTML files, and even multi-page TIFF files.
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 |
# File 'lib/cloudmersive-convert-api-client/api/convert_document_api.rb', line 94 def convert_document_autodetect_to_pdf_with_http_info(input_file, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: ConvertDocumentApi.convert_document_autodetect_to_pdf ..." end # verify the required parameter 'input_file' is set if @api_client.config.client_side_validation && input_file.nil? fail ArgumentError, "Missing the required parameter 'input_file' when calling ConvertDocumentApi.convert_document_autodetect_to_pdf" end # resource path local_var_path = "/convert/autodetect/to/pdf" # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/octet-stream']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['multipart/form-data']) # form parameters form_params = {} form_params["inputFile"] = input_file # http body (model) post_body = nil auth_names = ['Apikey'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'String') if @api_client.config.debugging @api_client.config.logger.debug "API called: ConvertDocumentApi#convert_document_autodetect_to_pdf\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#convert_document_autodetect_to_png_array(input_file, opts = {}) ⇒ AutodetectToPngResult
Convert Document to PNG array Automatically detect file type and convert it to an array of PNG images. Supports all of the major Office document file formats, over 100 image formats, and even multi-page TIFF files.
140 141 142 143 |
# File 'lib/cloudmersive-convert-api-client/api/convert_document_api.rb', line 140 def convert_document_autodetect_to_png_array(input_file, opts = {}) data, _status_code, _headers = convert_document_autodetect_to_png_array_with_http_info(input_file, opts) return data end |
#convert_document_autodetect_to_png_array_with_http_info(input_file, opts = {}) ⇒ Array<(AutodetectToPngResult, Fixnum, Hash)>
Convert Document to PNG array Automatically detect file type and convert it to an array of PNG images. Supports all of the major Office document file formats, over 100 image formats, and even multi-page TIFF files.
150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/cloudmersive-convert-api-client/api/convert_document_api.rb', line 150 def convert_document_autodetect_to_png_array_with_http_info(input_file, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: ConvertDocumentApi.convert_document_autodetect_to_png_array ..." end # verify the required parameter 'input_file' is set if @api_client.config.client_side_validation && input_file.nil? fail ArgumentError, "Missing the required parameter 'input_file' when calling ConvertDocumentApi.convert_document_autodetect_to_png_array" end # resource path local_var_path = "/convert/autodetect/to/png" # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/octet-stream']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['multipart/form-data']) # form parameters form_params = {} form_params["inputFile"] = input_file # http body (model) post_body = nil auth_names = ['Apikey'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'AutodetectToPngResult') if @api_client.config.debugging @api_client.config.logger.debug "API called: ConvertDocumentApi#convert_document_autodetect_to_png_array\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#convert_document_csv_to_xlsx(input_file, opts = {}) ⇒ String
CSV to Excel XLSX Convert CSV file to Office Excel XLSX Workbooks file format.
196 197 198 199 |
# File 'lib/cloudmersive-convert-api-client/api/convert_document_api.rb', line 196 def convert_document_csv_to_xlsx(input_file, opts = {}) data, _status_code, _headers = convert_document_csv_to_xlsx_with_http_info(input_file, opts) return data end |
#convert_document_csv_to_xlsx_with_http_info(input_file, opts = {}) ⇒ Array<(String, Fixnum, Hash)>
CSV to Excel XLSX Convert CSV file to Office Excel XLSX Workbooks file format.
206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 |
# File 'lib/cloudmersive-convert-api-client/api/convert_document_api.rb', line 206 def convert_document_csv_to_xlsx_with_http_info(input_file, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: ConvertDocumentApi.convert_document_csv_to_xlsx ..." end # verify the required parameter 'input_file' is set if @api_client.config.client_side_validation && input_file.nil? fail ArgumentError, "Missing the required parameter 'input_file' when calling ConvertDocumentApi.convert_document_csv_to_xlsx" end # resource path local_var_path = "/convert/csv/to/xlsx" # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/octet-stream']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['multipart/form-data']) # form parameters form_params = {} form_params["inputFile"] = input_file # http body (model) post_body = nil auth_names = ['Apikey'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'String') if @api_client.config.debugging @api_client.config.logger.debug "API called: ConvertDocumentApi#convert_document_csv_to_xlsx\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#convert_document_doc_to_docx(input_file, opts = {}) ⇒ String
Word DOC (97-03) to DOCX Convert/upgrade Office Word (97-2003 Format) Documents (doc) to the modern DOCX format
252 253 254 255 |
# File 'lib/cloudmersive-convert-api-client/api/convert_document_api.rb', line 252 def convert_document_doc_to_docx(input_file, opts = {}) data, _status_code, _headers = convert_document_doc_to_docx_with_http_info(input_file, opts) return data end |
#convert_document_doc_to_docx_with_http_info(input_file, opts = {}) ⇒ Array<(String, Fixnum, Hash)>
Word DOC (97-03) to DOCX Convert/upgrade Office Word (97-2003 Format) Documents (doc) to the modern DOCX format
262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 |
# File 'lib/cloudmersive-convert-api-client/api/convert_document_api.rb', line 262 def convert_document_doc_to_docx_with_http_info(input_file, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: ConvertDocumentApi.convert_document_doc_to_docx ..." end # verify the required parameter 'input_file' is set if @api_client.config.client_side_validation && input_file.nil? fail ArgumentError, "Missing the required parameter 'input_file' when calling ConvertDocumentApi.convert_document_doc_to_docx" end # resource path local_var_path = "/convert/doc/to/docx" # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/octet-stream']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['multipart/form-data']) # form parameters form_params = {} form_params["inputFile"] = input_file # http body (model) post_body = nil auth_names = ['Apikey'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'String') if @api_client.config.debugging @api_client.config.logger.debug "API called: ConvertDocumentApi#convert_document_doc_to_docx\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#convert_document_doc_to_pdf(input_file, opts = {}) ⇒ String
Word DOC (97-03) to PDF Convert Office Word (97-2003 Format) Documents (doc) to standard PDF
308 309 310 311 |
# File 'lib/cloudmersive-convert-api-client/api/convert_document_api.rb', line 308 def convert_document_doc_to_pdf(input_file, opts = {}) data, _status_code, _headers = convert_document_doc_to_pdf_with_http_info(input_file, opts) return data end |
#convert_document_doc_to_pdf_with_http_info(input_file, opts = {}) ⇒ Array<(String, Fixnum, Hash)>
Word DOC (97-03) to PDF Convert Office Word (97-2003 Format) Documents (doc) to standard PDF
318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 |
# File 'lib/cloudmersive-convert-api-client/api/convert_document_api.rb', line 318 def convert_document_doc_to_pdf_with_http_info(input_file, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: ConvertDocumentApi.convert_document_doc_to_pdf ..." end # verify the required parameter 'input_file' is set if @api_client.config.client_side_validation && input_file.nil? fail ArgumentError, "Missing the required parameter 'input_file' when calling ConvertDocumentApi.convert_document_doc_to_pdf" end # resource path local_var_path = "/convert/doc/to/pdf" # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/octet-stream']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['multipart/form-data']) # form parameters form_params = {} form_params["inputFile"] = input_file # http body (model) post_body = nil auth_names = ['Apikey'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'String') if @api_client.config.debugging @api_client.config.logger.debug "API called: ConvertDocumentApi#convert_document_doc_to_pdf\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#convert_document_docx_to_pdf(input_file, opts = {}) ⇒ String
Word DOCX to PDF Convert Office Word Documents (docx) to standard PDF
364 365 366 367 |
# File 'lib/cloudmersive-convert-api-client/api/convert_document_api.rb', line 364 def convert_document_docx_to_pdf(input_file, opts = {}) data, _status_code, _headers = convert_document_docx_to_pdf_with_http_info(input_file, opts) return data end |
#convert_document_docx_to_pdf_with_http_info(input_file, opts = {}) ⇒ Array<(String, Fixnum, Hash)>
Word DOCX to PDF Convert Office Word Documents (docx) to standard PDF
374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 |
# File 'lib/cloudmersive-convert-api-client/api/convert_document_api.rb', line 374 def convert_document_docx_to_pdf_with_http_info(input_file, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: ConvertDocumentApi.convert_document_docx_to_pdf ..." end # verify the required parameter 'input_file' is set if @api_client.config.client_side_validation && input_file.nil? fail ArgumentError, "Missing the required parameter 'input_file' when calling ConvertDocumentApi.convert_document_docx_to_pdf" end # resource path local_var_path = "/convert/docx/to/pdf" # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/octet-stream']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['multipart/form-data']) # form parameters form_params = {} form_params["inputFile"] = input_file # http body (model) post_body = nil auth_names = ['Apikey'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'String') if @api_client.config.debugging @api_client.config.logger.debug "API called: ConvertDocumentApi#convert_document_docx_to_pdf\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#convert_document_html_to_pdf(input_file, opts = {}) ⇒ String
HTML to PDF Convert standard HTML, with full support for CSS, JavaScript, Images, and other complex behavior to PDF. To use external files such as images, use an absolute URL to the file.
420 421 422 423 |
# File 'lib/cloudmersive-convert-api-client/api/convert_document_api.rb', line 420 def convert_document_html_to_pdf(input_file, opts = {}) data, _status_code, _headers = convert_document_html_to_pdf_with_http_info(input_file, opts) return data end |
#convert_document_html_to_pdf_with_http_info(input_file, opts = {}) ⇒ Array<(String, Fixnum, Hash)>
HTML to PDF Convert standard HTML, with full support for CSS, JavaScript, Images, and other complex behavior to PDF. To use external files such as images, use an absolute URL to the file.
430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 |
# File 'lib/cloudmersive-convert-api-client/api/convert_document_api.rb', line 430 def convert_document_html_to_pdf_with_http_info(input_file, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: ConvertDocumentApi.convert_document_html_to_pdf ..." end # verify the required parameter 'input_file' is set if @api_client.config.client_side_validation && input_file.nil? fail ArgumentError, "Missing the required parameter 'input_file' when calling ConvertDocumentApi.convert_document_html_to_pdf" end # resource path local_var_path = "/convert/html/to/pdf" # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/octet-stream']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['multipart/form-data']) # form parameters form_params = {} form_params["inputFile"] = input_file # http body (model) post_body = nil auth_names = ['Apikey'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'String') if @api_client.config.debugging @api_client.config.logger.debug "API called: ConvertDocumentApi#convert_document_html_to_pdf\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#convert_document_html_to_png(input_file, opts = {}) ⇒ PdfToPngResult
HTML to PNG array Convert standard HTML, with full support for CSS, JavaScript, Images, and other complex behavior to an array of PNG images, one for each page. To use external files in your HTML such as images, use an absolute URL to the file.
476 477 478 479 |
# File 'lib/cloudmersive-convert-api-client/api/convert_document_api.rb', line 476 def convert_document_html_to_png(input_file, opts = {}) data, _status_code, _headers = convert_document_html_to_png_with_http_info(input_file, opts) return data end |
#convert_document_html_to_png_with_http_info(input_file, opts = {}) ⇒ Array<(PdfToPngResult, Fixnum, Hash)>
HTML to PNG array Convert standard HTML, with full support for CSS, JavaScript, Images, and other complex behavior to an array of PNG images, one for each page. To use external files in your HTML such as images, use an absolute URL to the file.
486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 |
# File 'lib/cloudmersive-convert-api-client/api/convert_document_api.rb', line 486 def convert_document_html_to_png_with_http_info(input_file, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: ConvertDocumentApi.convert_document_html_to_png ..." end # verify the required parameter 'input_file' is set if @api_client.config.client_side_validation && input_file.nil? fail ArgumentError, "Missing the required parameter 'input_file' when calling ConvertDocumentApi.convert_document_html_to_png" end # resource path local_var_path = "/convert/html/to/png" # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/octet-stream']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['multipart/form-data']) # form parameters form_params = {} form_params["inputFile"] = input_file # http body (model) post_body = nil auth_names = ['Apikey'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'PdfToPngResult') if @api_client.config.debugging @api_client.config.logger.debug "API called: ConvertDocumentApi#convert_document_html_to_png\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#convert_document_pdf_to_docx(input_file, opts = {}) ⇒ String
PDF to Word DOCX Convert standard PDF to Office Word Documents (docx). Converts a PDF at high fidelity into Word format, where it can be easily edited and processed.
532 533 534 535 |
# File 'lib/cloudmersive-convert-api-client/api/convert_document_api.rb', line 532 def convert_document_pdf_to_docx(input_file, opts = {}) data, _status_code, _headers = convert_document_pdf_to_docx_with_http_info(input_file, opts) return data end |
#convert_document_pdf_to_docx_with_http_info(input_file, opts = {}) ⇒ Array<(String, Fixnum, Hash)>
PDF to Word DOCX Convert standard PDF to Office Word Documents (docx). Converts a PDF at high fidelity into Word format, where it can be easily edited and processed.
542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 |
# File 'lib/cloudmersive-convert-api-client/api/convert_document_api.rb', line 542 def convert_document_pdf_to_docx_with_http_info(input_file, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: ConvertDocumentApi.convert_document_pdf_to_docx ..." end # verify the required parameter 'input_file' is set if @api_client.config.client_side_validation && input_file.nil? fail ArgumentError, "Missing the required parameter 'input_file' when calling ConvertDocumentApi.convert_document_pdf_to_docx" end # resource path local_var_path = "/convert/pdf/to/docx" # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/octet-stream']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['multipart/form-data']) # form parameters form_params = {} form_params["inputFile"] = input_file # http body (model) post_body = nil auth_names = ['Apikey'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'String') if @api_client.config.debugging @api_client.config.logger.debug "API called: ConvertDocumentApi#convert_document_pdf_to_docx\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#convert_document_pdf_to_png_array(input_file, opts = {}) ⇒ PdfToPngResult
PDF to PNG Array Convert PDF document to PNG array, one image per page.
588 589 590 591 |
# File 'lib/cloudmersive-convert-api-client/api/convert_document_api.rb', line 588 def convert_document_pdf_to_png_array(input_file, opts = {}) data, _status_code, _headers = convert_document_pdf_to_png_array_with_http_info(input_file, opts) return data end |
#convert_document_pdf_to_png_array_with_http_info(input_file, opts = {}) ⇒ Array<(PdfToPngResult, Fixnum, Hash)>
PDF to PNG Array Convert PDF document to PNG array, one image per page.
598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 |
# File 'lib/cloudmersive-convert-api-client/api/convert_document_api.rb', line 598 def convert_document_pdf_to_png_array_with_http_info(input_file, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: ConvertDocumentApi.convert_document_pdf_to_png_array ..." end # verify the required parameter 'input_file' is set if @api_client.config.client_side_validation && input_file.nil? fail ArgumentError, "Missing the required parameter 'input_file' when calling ConvertDocumentApi.convert_document_pdf_to_png_array" end # resource path local_var_path = "/convert/pdf/to/png" # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/octet-stream']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['multipart/form-data']) # form parameters form_params = {} form_params["inputFile"] = input_file # http body (model) post_body = nil auth_names = ['Apikey'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'PdfToPngResult') if @api_client.config.debugging @api_client.config.logger.debug "API called: ConvertDocumentApi#convert_document_pdf_to_png_array\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#convert_document_pdf_to_pptx(input_file, opts = {}) ⇒ String
PDF to PowerPoint PPTX Convert standard PDF to Office PowerPoint Presentation (pptx). Converts a PDF file at high fidelity into PowerPoint format, where it can be easily edited and processed.
644 645 646 647 |
# File 'lib/cloudmersive-convert-api-client/api/convert_document_api.rb', line 644 def convert_document_pdf_to_pptx(input_file, opts = {}) data, _status_code, _headers = convert_document_pdf_to_pptx_with_http_info(input_file, opts) return data end |
#convert_document_pdf_to_pptx_with_http_info(input_file, opts = {}) ⇒ Array<(String, Fixnum, Hash)>
PDF to PowerPoint PPTX Convert standard PDF to Office PowerPoint Presentation (pptx). Converts a PDF file at high fidelity into PowerPoint format, where it can be easily edited and processed.
654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 |
# File 'lib/cloudmersive-convert-api-client/api/convert_document_api.rb', line 654 def convert_document_pdf_to_pptx_with_http_info(input_file, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: ConvertDocumentApi.convert_document_pdf_to_pptx ..." end # verify the required parameter 'input_file' is set if @api_client.config.client_side_validation && input_file.nil? fail ArgumentError, "Missing the required parameter 'input_file' when calling ConvertDocumentApi.convert_document_pdf_to_pptx" end # resource path local_var_path = "/convert/pdf/to/pptx" # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/octet-stream']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['multipart/form-data']) # form parameters form_params = {} form_params["inputFile"] = input_file # http body (model) post_body = nil auth_names = ['Apikey'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'String') if @api_client.config.debugging @api_client.config.logger.debug "API called: ConvertDocumentApi#convert_document_pdf_to_pptx\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#convert_document_ppt_to_pdf(input_file, opts = {}) ⇒ String
PowerPoint PPT (97-03) to PDF Convert Office PowerPoint (97-2003) Documents (ppt) to standard PDF
700 701 702 703 |
# File 'lib/cloudmersive-convert-api-client/api/convert_document_api.rb', line 700 def convert_document_ppt_to_pdf(input_file, opts = {}) data, _status_code, _headers = convert_document_ppt_to_pdf_with_http_info(input_file, opts) return data end |
#convert_document_ppt_to_pdf_with_http_info(input_file, opts = {}) ⇒ Array<(String, Fixnum, Hash)>
PowerPoint PPT (97-03) to PDF Convert Office PowerPoint (97-2003) Documents (ppt) to standard PDF
710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 |
# File 'lib/cloudmersive-convert-api-client/api/convert_document_api.rb', line 710 def convert_document_ppt_to_pdf_with_http_info(input_file, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: ConvertDocumentApi.convert_document_ppt_to_pdf ..." end # verify the required parameter 'input_file' is set if @api_client.config.client_side_validation && input_file.nil? fail ArgumentError, "Missing the required parameter 'input_file' when calling ConvertDocumentApi.convert_document_ppt_to_pdf" end # resource path local_var_path = "/convert/ppt/to/pdf" # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/octet-stream']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['multipart/form-data']) # form parameters form_params = {} form_params["inputFile"] = input_file # http body (model) post_body = nil auth_names = ['Apikey'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'String') if @api_client.config.debugging @api_client.config.logger.debug "API called: ConvertDocumentApi#convert_document_ppt_to_pdf\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#convert_document_ppt_to_pptx(input_file, opts = {}) ⇒ String
PowerPoint PPT (97-03) to PPTX Convert/upgrade Office PowerPoint (97-2003) Documents (ppt) to modern PPTX
756 757 758 759 |
# File 'lib/cloudmersive-convert-api-client/api/convert_document_api.rb', line 756 def convert_document_ppt_to_pptx(input_file, opts = {}) data, _status_code, _headers = convert_document_ppt_to_pptx_with_http_info(input_file, opts) return data end |
#convert_document_ppt_to_pptx_with_http_info(input_file, opts = {}) ⇒ Array<(String, Fixnum, Hash)>
PowerPoint PPT (97-03) to PPTX Convert/upgrade Office PowerPoint (97-2003) Documents (ppt) to modern PPTX
766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 |
# File 'lib/cloudmersive-convert-api-client/api/convert_document_api.rb', line 766 def convert_document_ppt_to_pptx_with_http_info(input_file, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: ConvertDocumentApi.convert_document_ppt_to_pptx ..." end # verify the required parameter 'input_file' is set if @api_client.config.client_side_validation && input_file.nil? fail ArgumentError, "Missing the required parameter 'input_file' when calling ConvertDocumentApi.convert_document_ppt_to_pptx" end # resource path local_var_path = "/convert/ppt/to/pptx" # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/octet-stream']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['multipart/form-data']) # form parameters form_params = {} form_params["inputFile"] = input_file # http body (model) post_body = nil auth_names = ['Apikey'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'String') if @api_client.config.debugging @api_client.config.logger.debug "API called: ConvertDocumentApi#convert_document_ppt_to_pptx\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#convert_document_pptx_to_pdf(input_file, opts = {}) ⇒ String
PowerPoint PPTX to PDF Convert Office PowerPoint Documents (pptx) to standard PDF
812 813 814 815 |
# File 'lib/cloudmersive-convert-api-client/api/convert_document_api.rb', line 812 def convert_document_pptx_to_pdf(input_file, opts = {}) data, _status_code, _headers = convert_document_pptx_to_pdf_with_http_info(input_file, opts) return data end |
#convert_document_pptx_to_pdf_with_http_info(input_file, opts = {}) ⇒ Array<(String, Fixnum, Hash)>
PowerPoint PPTX to PDF Convert Office PowerPoint Documents (pptx) to standard PDF
822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 |
# File 'lib/cloudmersive-convert-api-client/api/convert_document_api.rb', line 822 def convert_document_pptx_to_pdf_with_http_info(input_file, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: ConvertDocumentApi.convert_document_pptx_to_pdf ..." end # verify the required parameter 'input_file' is set if @api_client.config.client_side_validation && input_file.nil? fail ArgumentError, "Missing the required parameter 'input_file' when calling ConvertDocumentApi.convert_document_pptx_to_pdf" end # resource path local_var_path = "/convert/pptx/to/pdf" # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/octet-stream']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['multipart/form-data']) # form parameters form_params = {} form_params["inputFile"] = input_file # http body (model) post_body = nil auth_names = ['Apikey'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'String') if @api_client.config.debugging @api_client.config.logger.debug "API called: ConvertDocumentApi#convert_document_pptx_to_pdf\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#convert_document_xls_to_pdf(input_file, opts = {}) ⇒ String
Excel XLS (97-03) to PDF Convert Office Excel (97-2003) Workbooks (xls) to standard PDF. Converts all worksheets in the workbook to PDF.
868 869 870 871 |
# File 'lib/cloudmersive-convert-api-client/api/convert_document_api.rb', line 868 def convert_document_xls_to_pdf(input_file, opts = {}) data, _status_code, _headers = convert_document_xls_to_pdf_with_http_info(input_file, opts) return data end |
#convert_document_xls_to_pdf_with_http_info(input_file, opts = {}) ⇒ Array<(String, Fixnum, Hash)>
Excel XLS (97-03) to PDF Convert Office Excel (97-2003) Workbooks (xls) to standard PDF. Converts all worksheets in the workbook to PDF.
878 879 880 881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 |
# File 'lib/cloudmersive-convert-api-client/api/convert_document_api.rb', line 878 def convert_document_xls_to_pdf_with_http_info(input_file, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: ConvertDocumentApi.convert_document_xls_to_pdf ..." end # verify the required parameter 'input_file' is set if @api_client.config.client_side_validation && input_file.nil? fail ArgumentError, "Missing the required parameter 'input_file' when calling ConvertDocumentApi.convert_document_xls_to_pdf" end # resource path local_var_path = "/convert/xls/to/pdf" # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/octet-stream']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['multipart/form-data']) # form parameters form_params = {} form_params["inputFile"] = input_file # http body (model) post_body = nil auth_names = ['Apikey'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'String') if @api_client.config.debugging @api_client.config.logger.debug "API called: ConvertDocumentApi#convert_document_xls_to_pdf\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#convert_document_xls_to_xlsx(input_file, opts = {}) ⇒ String
Excel XLS (97-03) to XLSX Convert/upgrade Office Excel (97-2003) Workbooks (xls) to modern XLSX format.
924 925 926 927 |
# File 'lib/cloudmersive-convert-api-client/api/convert_document_api.rb', line 924 def convert_document_xls_to_xlsx(input_file, opts = {}) data, _status_code, _headers = convert_document_xls_to_xlsx_with_http_info(input_file, opts) return data end |
#convert_document_xls_to_xlsx_with_http_info(input_file, opts = {}) ⇒ Array<(String, Fixnum, Hash)>
Excel XLS (97-03) to XLSX Convert/upgrade Office Excel (97-2003) Workbooks (xls) to modern XLSX format.
934 935 936 937 938 939 940 941 942 943 944 945 946 947 948 949 950 951 952 953 954 955 956 957 958 959 960 961 962 963 964 965 966 967 968 969 970 971 972 973 |
# File 'lib/cloudmersive-convert-api-client/api/convert_document_api.rb', line 934 def convert_document_xls_to_xlsx_with_http_info(input_file, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: ConvertDocumentApi.convert_document_xls_to_xlsx ..." end # verify the required parameter 'input_file' is set if @api_client.config.client_side_validation && input_file.nil? fail ArgumentError, "Missing the required parameter 'input_file' when calling ConvertDocumentApi.convert_document_xls_to_xlsx" end # resource path local_var_path = "/convert/xls/to/xlsx" # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/octet-stream']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['multipart/form-data']) # form parameters form_params = {} form_params["inputFile"] = input_file # http body (model) post_body = nil auth_names = ['Apikey'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'String') if @api_client.config.debugging @api_client.config.logger.debug "API called: ConvertDocumentApi#convert_document_xls_to_xlsx\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#convert_document_xlsx_to_csv(input_file, opts = {}) ⇒ String
Excel XLSX to CSV Convert Office Excel Workbooks (xlsx) to standard Comma-Separated Values (CSV) format.
980 981 982 983 |
# File 'lib/cloudmersive-convert-api-client/api/convert_document_api.rb', line 980 def convert_document_xlsx_to_csv(input_file, opts = {}) data, _status_code, _headers = convert_document_xlsx_to_csv_with_http_info(input_file, opts) return data end |
#convert_document_xlsx_to_csv_with_http_info(input_file, opts = {}) ⇒ Array<(String, Fixnum, Hash)>
Excel XLSX to CSV Convert Office Excel Workbooks (xlsx) to standard Comma-Separated Values (CSV) format.
990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 |
# File 'lib/cloudmersive-convert-api-client/api/convert_document_api.rb', line 990 def convert_document_xlsx_to_csv_with_http_info(input_file, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: ConvertDocumentApi.convert_document_xlsx_to_csv ..." end # verify the required parameter 'input_file' is set if @api_client.config.client_side_validation && input_file.nil? fail ArgumentError, "Missing the required parameter 'input_file' when calling ConvertDocumentApi.convert_document_xlsx_to_csv" end # resource path local_var_path = "/convert/xlsx/to/csv" # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/octet-stream']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['multipart/form-data']) # form parameters form_params = {} form_params["inputFile"] = input_file # http body (model) post_body = nil auth_names = ['Apikey'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'String') if @api_client.config.debugging @api_client.config.logger.debug "API called: ConvertDocumentApi#convert_document_xlsx_to_csv\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#convert_document_xlsx_to_pdf(input_file, opts = {}) ⇒ String
Excel XLSX to PDF Convert Office Excel Workbooks (xlsx) to standard PDF. Converts all worksheets in the workbook to PDF.
1036 1037 1038 1039 |
# File 'lib/cloudmersive-convert-api-client/api/convert_document_api.rb', line 1036 def convert_document_xlsx_to_pdf(input_file, opts = {}) data, _status_code, _headers = convert_document_xlsx_to_pdf_with_http_info(input_file, opts) return data end |
#convert_document_xlsx_to_pdf_with_http_info(input_file, opts = {}) ⇒ Array<(String, Fixnum, Hash)>
Excel XLSX to PDF Convert Office Excel Workbooks (xlsx) to standard PDF. Converts all worksheets in the workbook to PDF.
1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 1077 1078 1079 1080 1081 1082 1083 1084 1085 |
# File 'lib/cloudmersive-convert-api-client/api/convert_document_api.rb', line 1046 def convert_document_xlsx_to_pdf_with_http_info(input_file, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: ConvertDocumentApi.convert_document_xlsx_to_pdf ..." end # verify the required parameter 'input_file' is set if @api_client.config.client_side_validation && input_file.nil? fail ArgumentError, "Missing the required parameter 'input_file' when calling ConvertDocumentApi.convert_document_xlsx_to_pdf" end # resource path local_var_path = "/convert/xlsx/to/pdf" # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/octet-stream']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['multipart/form-data']) # form parameters form_params = {} form_params["inputFile"] = input_file # http body (model) post_body = nil auth_names = ['Apikey'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'String') if @api_client.config.debugging @api_client.config.logger.debug "API called: ConvertDocumentApi#convert_document_xlsx_to_pdf\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |