Class: CloudmersiveConvertApiClient::EmlToHtmlResult
- Inherits:
-
Object
- Object
- CloudmersiveConvertApiClient::EmlToHtmlResult
- Defined in:
- lib/cloudmersive-convert-api-client/models/eml_to_html_result.rb
Overview
Result of converting an EML file to HTML string
Instance Attribute Summary collapse
-
#attachments ⇒ Object
List of all attachments for the EML file.
-
#bcc ⇒ Object
The BCC recipients of the EML file’s email.
-
#body ⇒ Object
The main body of the EML file’s email as an HTML string.
-
#cc ⇒ Object
The CC recipients of the EML file’s email.
-
#content ⇒ Object
An HTML string version of the EML file.
-
#from ⇒ Object
The From sender of the EML file’s email.
-
#organization ⇒ Object
The Organization of the EML file’s email.
-
#received_time ⇒ Object
The time that the EML file’s email was received.
-
#subject ⇒ Object
The subject of the EML file’s email.
-
#successful ⇒ Object
True if the operation was successful, false otherwise.
-
#to ⇒ Object
The To recipients of the EML file’s email.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ EmlToHtmlResult
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ EmlToHtmlResult
Initializes the object
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'lib/cloudmersive-convert-api-client/models/eml_to_html_result.rb', line 88 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}){|(k,v), h| h[k.to_sym] = v} if attributes.has_key?(:'Successful') self.successful = attributes[:'Successful'] end if attributes.has_key?(:'Content') self.content = attributes[:'Content'] end if attributes.has_key?(:'Body') self.body = attributes[:'Body'] end if attributes.has_key?(:'From') self.from = attributes[:'From'] end if attributes.has_key?(:'To') self.to = attributes[:'To'] end if attributes.has_key?(:'Cc') self.cc = attributes[:'Cc'] end if attributes.has_key?(:'Bcc') self.bcc = attributes[:'Bcc'] end if attributes.has_key?(:'ReceivedTime') self.received_time = attributes[:'ReceivedTime'] end if attributes.has_key?(:'Subject') self.subject = attributes[:'Subject'] end if attributes.has_key?(:'Organization') self.organization = attributes[:'Organization'] end if attributes.has_key?(:'Attachments') if (value = attributes[:'Attachments']).is_a?(Array) self. = value end end end |
Instance Attribute Details
#attachments ⇒ Object
List of all attachments for the EML file
49 50 51 |
# File 'lib/cloudmersive-convert-api-client/models/eml_to_html_result.rb', line 49 def end |
#bcc ⇒ Object
The BCC recipients of the EML file’s email
37 38 39 |
# File 'lib/cloudmersive-convert-api-client/models/eml_to_html_result.rb', line 37 def bcc @bcc end |
#body ⇒ Object
The main body of the EML file’s email as an HTML string
25 26 27 |
# File 'lib/cloudmersive-convert-api-client/models/eml_to_html_result.rb', line 25 def body @body end |
#cc ⇒ Object
The CC recipients of the EML file’s email
34 35 36 |
# File 'lib/cloudmersive-convert-api-client/models/eml_to_html_result.rb', line 34 def cc @cc end |
#content ⇒ Object
An HTML string version of the EML file
22 23 24 |
# File 'lib/cloudmersive-convert-api-client/models/eml_to_html_result.rb', line 22 def content @content end |
#from ⇒ Object
The From sender of the EML file’s email
28 29 30 |
# File 'lib/cloudmersive-convert-api-client/models/eml_to_html_result.rb', line 28 def from @from end |
#organization ⇒ Object
The Organization of the EML file’s email
46 47 48 |
# File 'lib/cloudmersive-convert-api-client/models/eml_to_html_result.rb', line 46 def organization @organization end |
#received_time ⇒ Object
The time that the EML file’s email was received
40 41 42 |
# File 'lib/cloudmersive-convert-api-client/models/eml_to_html_result.rb', line 40 def received_time @received_time end |
#subject ⇒ Object
The subject of the EML file’s email
43 44 45 |
# File 'lib/cloudmersive-convert-api-client/models/eml_to_html_result.rb', line 43 def subject @subject end |
#successful ⇒ Object
True if the operation was successful, false otherwise
19 20 21 |
# File 'lib/cloudmersive-convert-api-client/models/eml_to_html_result.rb', line 19 def successful @successful end |
#to ⇒ Object
The To recipients of the EML file’s email
31 32 33 |
# File 'lib/cloudmersive-convert-api-client/models/eml_to_html_result.rb', line 31 def to @to end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/cloudmersive-convert-api-client/models/eml_to_html_result.rb', line 53 def self.attribute_map { :'successful' => :'Successful', :'content' => :'Content', :'body' => :'Body', :'from' => :'From', :'to' => :'To', :'cc' => :'Cc', :'bcc' => :'Bcc', :'received_time' => :'ReceivedTime', :'subject' => :'Subject', :'organization' => :'Organization', :'attachments' => :'Attachments' } end |
.swagger_types ⇒ Object
Attribute type mapping.
70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/cloudmersive-convert-api-client/models/eml_to_html_result.rb', line 70 def self.swagger_types { :'successful' => :'BOOLEAN', :'content' => :'String', :'body' => :'String', :'from' => :'String', :'to' => :'String', :'cc' => :'String', :'bcc' => :'String', :'received_time' => :'String', :'subject' => :'String', :'organization' => :'String', :'attachments' => :'Array<EmlAttachment>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 |
# File 'lib/cloudmersive-convert-api-client/models/eml_to_html_result.rb', line 157 def ==(o) return true if self.equal?(o) self.class == o.class && successful == o.successful && content == o.content && body == o.body && from == o.from && to == o.to && cc == o.cc && bcc == o.bcc && received_time == o.received_time && subject == o.subject && organization == o.organization && == o. end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 |
# File 'lib/cloudmersive-convert-api-client/models/eml_to_html_result.rb', line 209 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = CloudmersiveConvertApiClient.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
275 276 277 278 279 280 281 282 283 284 285 286 287 |
# File 'lib/cloudmersive-convert-api-client/models/eml_to_html_result.rb', line 275 def _to_hash(value) if value.is_a?(Array) value.compact.map{ |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'lib/cloudmersive-convert-api-client/models/eml_to_html_result.rb', line 188 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
175 176 177 |
# File 'lib/cloudmersive-convert-api-client/models/eml_to_html_result.rb', line 175 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
181 182 183 |
# File 'lib/cloudmersive-convert-api-client/models/eml_to_html_result.rb', line 181 def hash [successful, content, body, from, to, cc, bcc, received_time, subject, organization, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
144 145 146 147 |
# File 'lib/cloudmersive-convert-api-client/models/eml_to_html_result.rb', line 144 def list_invalid_properties invalid_properties = Array.new return invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
255 256 257 |
# File 'lib/cloudmersive-convert-api-client/models/eml_to_html_result.rb', line 255 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
261 262 263 264 265 266 267 268 269 |
# File 'lib/cloudmersive-convert-api-client/models/eml_to_html_result.rb', line 261 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
249 250 251 |
# File 'lib/cloudmersive-convert-api-client/models/eml_to_html_result.rb', line 249 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
151 152 153 |
# File 'lib/cloudmersive-convert-api-client/models/eml_to_html_result.rb', line 151 def valid? return true end |