Class: CloudmersiveConvertApiClient::MergeDocumentApi

Inherits:
Object
  • Object
show all
Defined in:
lib/cloudmersive-convert-api-client/api/merge_document_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ MergeDocumentApi

Returns a new instance of MergeDocumentApi.



19
20
21
# File 'lib/cloudmersive-convert-api-client/api/merge_document_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/cloudmersive-convert-api-client/api/merge_document_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#merge_document_docx(input_file1, input_file2, opts = {}) ⇒ String

Merge Two Word DOCX Together Combine two Office Word Documents (docx) into one single Office Word document

Parameters:

  • input_file1

    First input file to perform the operation on.

  • input_file2

    Second input file to perform the operation on (more than 2 can be supplied).

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (String)


29
30
31
32
# File 'lib/cloudmersive-convert-api-client/api/merge_document_api.rb', line 29

def merge_document_docx(input_file1, input_file2, opts = {})
  data, _status_code, _headers = merge_document_docx_with_http_info(input_file1, input_file2, opts)
  return data
end

#merge_document_docx_multi(input_file1, input_file2, opts = {}) ⇒ String

Merge Multple Word DOCX Together Combine multiple Office Word Documents (docx) into one single Office Word document

Parameters:

  • input_file1

    First input file to perform the operation on.

  • input_file2

    Second input file to perform the operation on.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :input_file3 (File)

    Third input file to perform the operation on.

  • :input_file4 (File)

    Fourth input file to perform the operation on.

  • :input_file5 (File)

    Fifth input file to perform the operation on.

  • :input_file6 (File)

    Sixth input file to perform the operation on.

  • :input_file7 (File)

    Seventh input file to perform the operation on.

  • :input_file8 (File)

    Eighth input file to perform the operation on.

  • :input_file9 (File)

    Ninth input file to perform the operation on.

  • :input_file10 (File)

    Tenth input file to perform the operation on.

Returns:

  • (String)


100
101
102
103
# File 'lib/cloudmersive-convert-api-client/api/merge_document_api.rb', line 100

def merge_document_docx_multi(input_file1, input_file2, opts = {})
  data, _status_code, _headers = merge_document_docx_multi_with_http_info(input_file1, input_file2, opts)
  return data
end

#merge_document_docx_multi_with_http_info(input_file1, input_file2, opts = {}) ⇒ Array<(String, Fixnum, Hash)>

Merge Multple Word DOCX Together Combine multiple Office Word Documents (docx) into one single Office Word document

Parameters:

  • input_file1

    First input file to perform the operation on.

  • input_file2

    Second input file to perform the operation on.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :input_file3 (File)

    Third input file to perform the operation on.

  • :input_file4 (File)

    Fourth input file to perform the operation on.

  • :input_file5 (File)

    Fifth input file to perform the operation on.

  • :input_file6 (File)

    Sixth input file to perform the operation on.

  • :input_file7 (File)

    Seventh input file to perform the operation on.

  • :input_file8 (File)

    Eighth input file to perform the operation on.

  • :input_file9 (File)

    Ninth input file to perform the operation on.

  • :input_file10 (File)

    Tenth input file to perform the operation on.

Returns:

  • (Array<(String, Fixnum, Hash)>)

    String data, response status code and response headers



119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
# File 'lib/cloudmersive-convert-api-client/api/merge_document_api.rb', line 119

def merge_document_docx_multi_with_http_info(input_file1, input_file2, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: MergeDocumentApi.merge_document_docx_multi ..."
  end
  # verify the required parameter 'input_file1' is set
  if @api_client.config.client_side_validation && input_file1.nil?
    fail ArgumentError, "Missing the required parameter 'input_file1' when calling MergeDocumentApi.merge_document_docx_multi"
  end
  # verify the required parameter 'input_file2' is set
  if @api_client.config.client_side_validation && input_file2.nil?
    fail ArgumentError, "Missing the required parameter 'input_file2' when calling MergeDocumentApi.merge_document_docx_multi"
  end
  # resource path
  local_var_path = "/convert/merge/docx/multi"

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/octet-stream'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['multipart/form-data'])

  # form parameters
  form_params = {}
  form_params["inputFile1"] = input_file1
  form_params["inputFile2"] = input_file2
  form_params["inputFile3"] = opts[:'input_file3'] if !opts[:'input_file3'].nil?
  form_params["inputFile4"] = opts[:'input_file4'] if !opts[:'input_file4'].nil?
  form_params["inputFile5"] = opts[:'input_file5'] if !opts[:'input_file5'].nil?
  form_params["inputFile6"] = opts[:'input_file6'] if !opts[:'input_file6'].nil?
  form_params["inputFile7"] = opts[:'input_file7'] if !opts[:'input_file7'].nil?
  form_params["inputFile8"] = opts[:'input_file8'] if !opts[:'input_file8'].nil?
  form_params["inputFile9"] = opts[:'input_file9'] if !opts[:'input_file9'].nil?
  form_params["inputFile10"] = opts[:'input_file10'] if !opts[:'input_file10'].nil?

  # http body (model)
  post_body = nil
  auth_names = ['Apikey']
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'String')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: MergeDocumentApi#merge_document_docx_multi\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#merge_document_docx_with_http_info(input_file1, input_file2, opts = {}) ⇒ Array<(String, Fixnum, Hash)>

Merge Two Word DOCX Together Combine two Office Word Documents (docx) into one single Office Word document

Parameters:

  • input_file1

    First input file to perform the operation on.

  • input_file2

    Second input file to perform the operation on (more than 2 can be supplied).

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(String, Fixnum, Hash)>)

    String data, response status code and response headers



40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/cloudmersive-convert-api-client/api/merge_document_api.rb', line 40

def merge_document_docx_with_http_info(input_file1, input_file2, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: MergeDocumentApi.merge_document_docx ..."
  end
  # verify the required parameter 'input_file1' is set
  if @api_client.config.client_side_validation && input_file1.nil?
    fail ArgumentError, "Missing the required parameter 'input_file1' when calling MergeDocumentApi.merge_document_docx"
  end
  # verify the required parameter 'input_file2' is set
  if @api_client.config.client_side_validation && input_file2.nil?
    fail ArgumentError, "Missing the required parameter 'input_file2' when calling MergeDocumentApi.merge_document_docx"
  end
  # resource path
  local_var_path = "/convert/merge/docx"

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/octet-stream'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['multipart/form-data'])

  # form parameters
  form_params = {}
  form_params["inputFile1"] = input_file1
  form_params["inputFile2"] = input_file2

  # http body (model)
  post_body = nil
  auth_names = ['Apikey']
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'String')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: MergeDocumentApi#merge_document_docx\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#merge_document_pdf(input_file1, input_file2, opts = {}) ⇒ String

Merge Two PDF Files Together Combine two PDF files (pdf) into a single PDF document, preserving the order of the input documents in the combined document

Parameters:

  • input_file1

    First input file to perform the operation on.

  • input_file2

    Second input file to perform the operation on (more than 2 can be supplied).

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (String)


179
180
181
182
# File 'lib/cloudmersive-convert-api-client/api/merge_document_api.rb', line 179

def merge_document_pdf(input_file1, input_file2, opts = {})
  data, _status_code, _headers = merge_document_pdf_with_http_info(input_file1, input_file2, opts)
  return data
end

#merge_document_pdf_multi(input_file1, input_file2, opts = {}) ⇒ String

Merge Multple PDF Files Together Combine multiple PDF files (pdf) into a single PDF document, preserving the order of the input documents in the combined document

Parameters:

  • input_file1

    First input file to perform the operation on.

  • input_file2

    Second input file to perform the operation on.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :input_file3 (File)

    Third input file to perform the operation on.

  • :input_file4 (File)

    Fourth input file to perform the operation on.

  • :input_file5 (File)

    Fifth input file to perform the operation on.

  • :input_file6 (File)

    Sixth input file to perform the operation on.

  • :input_file7 (File)

    Seventh input file to perform the operation on.

  • :input_file8 (File)

    Eighth input file to perform the operation on.

  • :input_file9 (File)

    Ninth input file to perform the operation on.

  • :input_file10 (File)

    Tenth input file to perform the operation on.

Returns:

  • (String)


250
251
252
253
# File 'lib/cloudmersive-convert-api-client/api/merge_document_api.rb', line 250

def merge_document_pdf_multi(input_file1, input_file2, opts = {})
  data, _status_code, _headers = merge_document_pdf_multi_with_http_info(input_file1, input_file2, opts)
  return data
end

#merge_document_pdf_multi_with_http_info(input_file1, input_file2, opts = {}) ⇒ Array<(String, Fixnum, Hash)>

Merge Multple PDF Files Together Combine multiple PDF files (pdf) into a single PDF document, preserving the order of the input documents in the combined document

Parameters:

  • input_file1

    First input file to perform the operation on.

  • input_file2

    Second input file to perform the operation on.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :input_file3 (File)

    Third input file to perform the operation on.

  • :input_file4 (File)

    Fourth input file to perform the operation on.

  • :input_file5 (File)

    Fifth input file to perform the operation on.

  • :input_file6 (File)

    Sixth input file to perform the operation on.

  • :input_file7 (File)

    Seventh input file to perform the operation on.

  • :input_file8 (File)

    Eighth input file to perform the operation on.

  • :input_file9 (File)

    Ninth input file to perform the operation on.

  • :input_file10 (File)

    Tenth input file to perform the operation on.

Returns:

  • (Array<(String, Fixnum, Hash)>)

    String data, response status code and response headers



269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
# File 'lib/cloudmersive-convert-api-client/api/merge_document_api.rb', line 269

def merge_document_pdf_multi_with_http_info(input_file1, input_file2, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: MergeDocumentApi.merge_document_pdf_multi ..."
  end
  # verify the required parameter 'input_file1' is set
  if @api_client.config.client_side_validation && input_file1.nil?
    fail ArgumentError, "Missing the required parameter 'input_file1' when calling MergeDocumentApi.merge_document_pdf_multi"
  end
  # verify the required parameter 'input_file2' is set
  if @api_client.config.client_side_validation && input_file2.nil?
    fail ArgumentError, "Missing the required parameter 'input_file2' when calling MergeDocumentApi.merge_document_pdf_multi"
  end
  # resource path
  local_var_path = "/convert/merge/pdf/multi"

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/octet-stream'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['multipart/form-data'])

  # form parameters
  form_params = {}
  form_params["inputFile1"] = input_file1
  form_params["inputFile2"] = input_file2
  form_params["inputFile3"] = opts[:'input_file3'] if !opts[:'input_file3'].nil?
  form_params["inputFile4"] = opts[:'input_file4'] if !opts[:'input_file4'].nil?
  form_params["inputFile5"] = opts[:'input_file5'] if !opts[:'input_file5'].nil?
  form_params["inputFile6"] = opts[:'input_file6'] if !opts[:'input_file6'].nil?
  form_params["inputFile7"] = opts[:'input_file7'] if !opts[:'input_file7'].nil?
  form_params["inputFile8"] = opts[:'input_file8'] if !opts[:'input_file8'].nil?
  form_params["inputFile9"] = opts[:'input_file9'] if !opts[:'input_file9'].nil?
  form_params["inputFile10"] = opts[:'input_file10'] if !opts[:'input_file10'].nil?

  # http body (model)
  post_body = nil
  auth_names = ['Apikey']
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'String')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: MergeDocumentApi#merge_document_pdf_multi\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#merge_document_pdf_with_http_info(input_file1, input_file2, opts = {}) ⇒ Array<(String, Fixnum, Hash)>

Merge Two PDF Files Together Combine two PDF files (pdf) into a single PDF document, preserving the order of the input documents in the combined document

Parameters:

  • input_file1

    First input file to perform the operation on.

  • input_file2

    Second input file to perform the operation on (more than 2 can be supplied).

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(String, Fixnum, Hash)>)

    String data, response status code and response headers



190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
# File 'lib/cloudmersive-convert-api-client/api/merge_document_api.rb', line 190

def merge_document_pdf_with_http_info(input_file1, input_file2, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: MergeDocumentApi.merge_document_pdf ..."
  end
  # verify the required parameter 'input_file1' is set
  if @api_client.config.client_side_validation && input_file1.nil?
    fail ArgumentError, "Missing the required parameter 'input_file1' when calling MergeDocumentApi.merge_document_pdf"
  end
  # verify the required parameter 'input_file2' is set
  if @api_client.config.client_side_validation && input_file2.nil?
    fail ArgumentError, "Missing the required parameter 'input_file2' when calling MergeDocumentApi.merge_document_pdf"
  end
  # resource path
  local_var_path = "/convert/merge/pdf"

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/octet-stream'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['multipart/form-data'])

  # form parameters
  form_params = {}
  form_params["inputFile1"] = input_file1
  form_params["inputFile2"] = input_file2

  # http body (model)
  post_body = nil
  auth_names = ['Apikey']
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'String')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: MergeDocumentApi#merge_document_pdf\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#merge_document_png(input_file1, input_file2, opts = {}) ⇒ String

Merge Two PNG Files Together Combine two PNG files into a single PNG document, preserving the order of the input documents in the combined document by stacking them vertically

Parameters:

  • input_file1

    First input file to perform the operation on.

  • input_file2

    Second input file to perform the operation on (more than 2 can be supplied).

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (String)


329
330
331
332
# File 'lib/cloudmersive-convert-api-client/api/merge_document_api.rb', line 329

def merge_document_png(input_file1, input_file2, opts = {})
  data, _status_code, _headers = merge_document_png_with_http_info(input_file1, input_file2, opts)
  return data
end

#merge_document_png_multi(input_file1, input_file2, opts = {}) ⇒ String

Merge Multple PNG Files Together Combine multiple PNG files into a single PNG document, preserving the order of the input documents in the combined document by stacking them vertically

Parameters:

  • input_file1

    First input file to perform the operation on.

  • input_file2

    Second input file to perform the operation on.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :input_file3 (File)

    Third input file to perform the operation on.

  • :input_file4 (File)

    Fourth input file to perform the operation on.

  • :input_file5 (File)

    Fifth input file to perform the operation on.

  • :input_file6 (File)

    Sixth input file to perform the operation on.

  • :input_file7 (File)

    Seventh input file to perform the operation on.

  • :input_file8 (File)

    Eighth input file to perform the operation on.

  • :input_file9 (File)

    Ninth input file to perform the operation on.

  • :input_file10 (File)

    Tenth input file to perform the operation on.

Returns:

  • (String)


400
401
402
403
# File 'lib/cloudmersive-convert-api-client/api/merge_document_api.rb', line 400

def merge_document_png_multi(input_file1, input_file2, opts = {})
  data, _status_code, _headers = merge_document_png_multi_with_http_info(input_file1, input_file2, opts)
  return data
end

#merge_document_png_multi_with_http_info(input_file1, input_file2, opts = {}) ⇒ Array<(String, Fixnum, Hash)>

Merge Multple PNG Files Together Combine multiple PNG files into a single PNG document, preserving the order of the input documents in the combined document by stacking them vertically

Parameters:

  • input_file1

    First input file to perform the operation on.

  • input_file2

    Second input file to perform the operation on.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :input_file3 (File)

    Third input file to perform the operation on.

  • :input_file4 (File)

    Fourth input file to perform the operation on.

  • :input_file5 (File)

    Fifth input file to perform the operation on.

  • :input_file6 (File)

    Sixth input file to perform the operation on.

  • :input_file7 (File)

    Seventh input file to perform the operation on.

  • :input_file8 (File)

    Eighth input file to perform the operation on.

  • :input_file9 (File)

    Ninth input file to perform the operation on.

  • :input_file10 (File)

    Tenth input file to perform the operation on.

Returns:

  • (Array<(String, Fixnum, Hash)>)

    String data, response status code and response headers



419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
# File 'lib/cloudmersive-convert-api-client/api/merge_document_api.rb', line 419

def merge_document_png_multi_with_http_info(input_file1, input_file2, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: MergeDocumentApi.merge_document_png_multi ..."
  end
  # verify the required parameter 'input_file1' is set
  if @api_client.config.client_side_validation && input_file1.nil?
    fail ArgumentError, "Missing the required parameter 'input_file1' when calling MergeDocumentApi.merge_document_png_multi"
  end
  # verify the required parameter 'input_file2' is set
  if @api_client.config.client_side_validation && input_file2.nil?
    fail ArgumentError, "Missing the required parameter 'input_file2' when calling MergeDocumentApi.merge_document_png_multi"
  end
  # resource path
  local_var_path = "/convert/merge/png/vertical/multi"

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/octet-stream'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['multipart/form-data'])

  # form parameters
  form_params = {}
  form_params["inputFile1"] = input_file1
  form_params["inputFile2"] = input_file2
  form_params["inputFile3"] = opts[:'input_file3'] if !opts[:'input_file3'].nil?
  form_params["inputFile4"] = opts[:'input_file4'] if !opts[:'input_file4'].nil?
  form_params["inputFile5"] = opts[:'input_file5'] if !opts[:'input_file5'].nil?
  form_params["inputFile6"] = opts[:'input_file6'] if !opts[:'input_file6'].nil?
  form_params["inputFile7"] = opts[:'input_file7'] if !opts[:'input_file7'].nil?
  form_params["inputFile8"] = opts[:'input_file8'] if !opts[:'input_file8'].nil?
  form_params["inputFile9"] = opts[:'input_file9'] if !opts[:'input_file9'].nil?
  form_params["inputFile10"] = opts[:'input_file10'] if !opts[:'input_file10'].nil?

  # http body (model)
  post_body = nil
  auth_names = ['Apikey']
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'String')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: MergeDocumentApi#merge_document_png_multi\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#merge_document_png_with_http_info(input_file1, input_file2, opts = {}) ⇒ Array<(String, Fixnum, Hash)>

Merge Two PNG Files Together Combine two PNG files into a single PNG document, preserving the order of the input documents in the combined document by stacking them vertically

Parameters:

  • input_file1

    First input file to perform the operation on.

  • input_file2

    Second input file to perform the operation on (more than 2 can be supplied).

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(String, Fixnum, Hash)>)

    String data, response status code and response headers



340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
# File 'lib/cloudmersive-convert-api-client/api/merge_document_api.rb', line 340

def merge_document_png_with_http_info(input_file1, input_file2, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: MergeDocumentApi.merge_document_png ..."
  end
  # verify the required parameter 'input_file1' is set
  if @api_client.config.client_side_validation && input_file1.nil?
    fail ArgumentError, "Missing the required parameter 'input_file1' when calling MergeDocumentApi.merge_document_png"
  end
  # verify the required parameter 'input_file2' is set
  if @api_client.config.client_side_validation && input_file2.nil?
    fail ArgumentError, "Missing the required parameter 'input_file2' when calling MergeDocumentApi.merge_document_png"
  end
  # resource path
  local_var_path = "/convert/merge/png/vertical"

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/octet-stream'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['multipart/form-data'])

  # form parameters
  form_params = {}
  form_params["inputFile1"] = input_file1
  form_params["inputFile2"] = input_file2

  # http body (model)
  post_body = nil
  auth_names = ['Apikey']
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'String')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: MergeDocumentApi#merge_document_png\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#merge_document_pptx(input_file1, input_file2, opts = {}) ⇒ String

Merge Two PowerPoint PPTX Together Combine two Office PowerPoint presentations (pptx) into one single Office PowerPoint presentation

Parameters:

  • input_file1

    First input file to perform the operation on.

  • input_file2

    Second input file to perform the operation on (more than 2 can be supplied).

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (String)


479
480
481
482
# File 'lib/cloudmersive-convert-api-client/api/merge_document_api.rb', line 479

def merge_document_pptx(input_file1, input_file2, opts = {})
  data, _status_code, _headers = merge_document_pptx_with_http_info(input_file1, input_file2, opts)
  return data
end

#merge_document_pptx_multi(input_file1, input_file2, opts = {}) ⇒ String

Merge Multple PowerPoint PPTX Together Combine multiple Office PowerPoint presentations (pptx) into one single Office PowerPoint presentation

Parameters:

  • input_file1

    First input file to perform the operation on.

  • input_file2

    Second input file to perform the operation on.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :input_file3 (File)

    Third input file to perform the operation on.

  • :input_file4 (File)

    Fourth input file to perform the operation on.

  • :input_file5 (File)

    Fifth input file to perform the operation on.

  • :input_file6 (File)

    Sixth input file to perform the operation on.

  • :input_file7 (File)

    Seventh input file to perform the operation on.

  • :input_file8 (File)

    Eighth input file to perform the operation on.

  • :input_file9 (File)

    Ninth input file to perform the operation on.

  • :input_file10 (File)

    Tenth input file to perform the operation on.

Returns:

  • (String)


550
551
552
553
# File 'lib/cloudmersive-convert-api-client/api/merge_document_api.rb', line 550

def merge_document_pptx_multi(input_file1, input_file2, opts = {})
  data, _status_code, _headers = merge_document_pptx_multi_with_http_info(input_file1, input_file2, opts)
  return data
end

#merge_document_pptx_multi_with_http_info(input_file1, input_file2, opts = {}) ⇒ Array<(String, Fixnum, Hash)>

Merge Multple PowerPoint PPTX Together Combine multiple Office PowerPoint presentations (pptx) into one single Office PowerPoint presentation

Parameters:

  • input_file1

    First input file to perform the operation on.

  • input_file2

    Second input file to perform the operation on.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :input_file3 (File)

    Third input file to perform the operation on.

  • :input_file4 (File)

    Fourth input file to perform the operation on.

  • :input_file5 (File)

    Fifth input file to perform the operation on.

  • :input_file6 (File)

    Sixth input file to perform the operation on.

  • :input_file7 (File)

    Seventh input file to perform the operation on.

  • :input_file8 (File)

    Eighth input file to perform the operation on.

  • :input_file9 (File)

    Ninth input file to perform the operation on.

  • :input_file10 (File)

    Tenth input file to perform the operation on.

Returns:

  • (Array<(String, Fixnum, Hash)>)

    String data, response status code and response headers



569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
# File 'lib/cloudmersive-convert-api-client/api/merge_document_api.rb', line 569

def merge_document_pptx_multi_with_http_info(input_file1, input_file2, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: MergeDocumentApi.merge_document_pptx_multi ..."
  end
  # verify the required parameter 'input_file1' is set
  if @api_client.config.client_side_validation && input_file1.nil?
    fail ArgumentError, "Missing the required parameter 'input_file1' when calling MergeDocumentApi.merge_document_pptx_multi"
  end
  # verify the required parameter 'input_file2' is set
  if @api_client.config.client_side_validation && input_file2.nil?
    fail ArgumentError, "Missing the required parameter 'input_file2' when calling MergeDocumentApi.merge_document_pptx_multi"
  end
  # resource path
  local_var_path = "/convert/merge/pptx/multi"

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/octet-stream'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['multipart/form-data'])

  # form parameters
  form_params = {}
  form_params["inputFile1"] = input_file1
  form_params["inputFile2"] = input_file2
  form_params["inputFile3"] = opts[:'input_file3'] if !opts[:'input_file3'].nil?
  form_params["inputFile4"] = opts[:'input_file4'] if !opts[:'input_file4'].nil?
  form_params["inputFile5"] = opts[:'input_file5'] if !opts[:'input_file5'].nil?
  form_params["inputFile6"] = opts[:'input_file6'] if !opts[:'input_file6'].nil?
  form_params["inputFile7"] = opts[:'input_file7'] if !opts[:'input_file7'].nil?
  form_params["inputFile8"] = opts[:'input_file8'] if !opts[:'input_file8'].nil?
  form_params["inputFile9"] = opts[:'input_file9'] if !opts[:'input_file9'].nil?
  form_params["inputFile10"] = opts[:'input_file10'] if !opts[:'input_file10'].nil?

  # http body (model)
  post_body = nil
  auth_names = ['Apikey']
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'String')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: MergeDocumentApi#merge_document_pptx_multi\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#merge_document_pptx_with_http_info(input_file1, input_file2, opts = {}) ⇒ Array<(String, Fixnum, Hash)>

Merge Two PowerPoint PPTX Together Combine two Office PowerPoint presentations (pptx) into one single Office PowerPoint presentation

Parameters:

  • input_file1

    First input file to perform the operation on.

  • input_file2

    Second input file to perform the operation on (more than 2 can be supplied).

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(String, Fixnum, Hash)>)

    String data, response status code and response headers



490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
# File 'lib/cloudmersive-convert-api-client/api/merge_document_api.rb', line 490

def merge_document_pptx_with_http_info(input_file1, input_file2, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: MergeDocumentApi.merge_document_pptx ..."
  end
  # verify the required parameter 'input_file1' is set
  if @api_client.config.client_side_validation && input_file1.nil?
    fail ArgumentError, "Missing the required parameter 'input_file1' when calling MergeDocumentApi.merge_document_pptx"
  end
  # verify the required parameter 'input_file2' is set
  if @api_client.config.client_side_validation && input_file2.nil?
    fail ArgumentError, "Missing the required parameter 'input_file2' when calling MergeDocumentApi.merge_document_pptx"
  end
  # resource path
  local_var_path = "/convert/merge/pptx"

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/octet-stream'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['multipart/form-data'])

  # form parameters
  form_params = {}
  form_params["inputFile1"] = input_file1
  form_params["inputFile2"] = input_file2

  # http body (model)
  post_body = nil
  auth_names = ['Apikey']
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'String')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: MergeDocumentApi#merge_document_pptx\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#merge_document_txt(input_file1, input_file2, opts = {}) ⇒ Object

Merge Two Text (TXT) Files Together Combine two Text (.TXT) files into a single text document, preserving the order of the input documents in the combined document by stacking them vertically.

Parameters:

  • input_file1

    First input file to perform the operation on.

  • input_file2

    Second input file to perform the operation on (more than 2 can be supplied).

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Object)


629
630
631
632
# File 'lib/cloudmersive-convert-api-client/api/merge_document_api.rb', line 629

def merge_document_txt(input_file1, input_file2, opts = {})
  data, _status_code, _headers = merge_document_txt_with_http_info(input_file1, input_file2, opts)
  return data
end

#merge_document_txt_multi(input_file1, input_file2, opts = {}) ⇒ String

Merge Multple Text (TXT) Files Together Combine multiple Text (.TXT) files into a single text document, preserving the order of the input documents in the combined document by stacking them vertically.

Parameters:

  • input_file1

    First input file to perform the operation on.

  • input_file2

    Second input file to perform the operation on.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :input_file3 (File)

    Third input file to perform the operation on.

  • :input_file4 (File)

    Fourth input file to perform the operation on.

  • :input_file5 (File)

    Fifth input file to perform the operation on.

  • :input_file6 (File)

    Sixth input file to perform the operation on.

  • :input_file7 (File)

    Seventh input file to perform the operation on.

  • :input_file8 (File)

    Eighth input file to perform the operation on.

  • :input_file9 (File)

    Ninth input file to perform the operation on.

  • :input_file10 (File)

    Tenth input file to perform the operation on.

Returns:

  • (String)


700
701
702
703
# File 'lib/cloudmersive-convert-api-client/api/merge_document_api.rb', line 700

def merge_document_txt_multi(input_file1, input_file2, opts = {})
  data, _status_code, _headers = merge_document_txt_multi_with_http_info(input_file1, input_file2, opts)
  return data
end

#merge_document_txt_multi_with_http_info(input_file1, input_file2, opts = {}) ⇒ Array<(String, Fixnum, Hash)>

Merge Multple Text (TXT) Files Together Combine multiple Text (.TXT) files into a single text document, preserving the order of the input documents in the combined document by stacking them vertically.

Parameters:

  • input_file1

    First input file to perform the operation on.

  • input_file2

    Second input file to perform the operation on.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :input_file3 (File)

    Third input file to perform the operation on.

  • :input_file4 (File)

    Fourth input file to perform the operation on.

  • :input_file5 (File)

    Fifth input file to perform the operation on.

  • :input_file6 (File)

    Sixth input file to perform the operation on.

  • :input_file7 (File)

    Seventh input file to perform the operation on.

  • :input_file8 (File)

    Eighth input file to perform the operation on.

  • :input_file9 (File)

    Ninth input file to perform the operation on.

  • :input_file10 (File)

    Tenth input file to perform the operation on.

Returns:

  • (Array<(String, Fixnum, Hash)>)

    String data, response status code and response headers



719
720
721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
769
770
771
# File 'lib/cloudmersive-convert-api-client/api/merge_document_api.rb', line 719

def merge_document_txt_multi_with_http_info(input_file1, input_file2, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: MergeDocumentApi.merge_document_txt_multi ..."
  end
  # verify the required parameter 'input_file1' is set
  if @api_client.config.client_side_validation && input_file1.nil?
    fail ArgumentError, "Missing the required parameter 'input_file1' when calling MergeDocumentApi.merge_document_txt_multi"
  end
  # verify the required parameter 'input_file2' is set
  if @api_client.config.client_side_validation && input_file2.nil?
    fail ArgumentError, "Missing the required parameter 'input_file2' when calling MergeDocumentApi.merge_document_txt_multi"
  end
  # resource path
  local_var_path = "/convert/merge/txt/multi"

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/octet-stream'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['multipart/form-data'])

  # form parameters
  form_params = {}
  form_params["inputFile1"] = input_file1
  form_params["inputFile2"] = input_file2
  form_params["inputFile3"] = opts[:'input_file3'] if !opts[:'input_file3'].nil?
  form_params["inputFile4"] = opts[:'input_file4'] if !opts[:'input_file4'].nil?
  form_params["inputFile5"] = opts[:'input_file5'] if !opts[:'input_file5'].nil?
  form_params["inputFile6"] = opts[:'input_file6'] if !opts[:'input_file6'].nil?
  form_params["inputFile7"] = opts[:'input_file7'] if !opts[:'input_file7'].nil?
  form_params["inputFile8"] = opts[:'input_file8'] if !opts[:'input_file8'].nil?
  form_params["inputFile9"] = opts[:'input_file9'] if !opts[:'input_file9'].nil?
  form_params["inputFile10"] = opts[:'input_file10'] if !opts[:'input_file10'].nil?

  # http body (model)
  post_body = nil
  auth_names = ['Apikey']
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'String')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: MergeDocumentApi#merge_document_txt_multi\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#merge_document_txt_with_http_info(input_file1, input_file2, opts = {}) ⇒ Array<(Object, Fixnum, Hash)>

Merge Two Text (TXT) Files Together Combine two Text (.TXT) files into a single text document, preserving the order of the input documents in the combined document by stacking them vertically.

Parameters:

  • input_file1

    First input file to perform the operation on.

  • input_file2

    Second input file to perform the operation on (more than 2 can be supplied).

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(Object, Fixnum, Hash)>)

    Object data, response status code and response headers



640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
# File 'lib/cloudmersive-convert-api-client/api/merge_document_api.rb', line 640

def merge_document_txt_with_http_info(input_file1, input_file2, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: MergeDocumentApi.merge_document_txt ..."
  end
  # verify the required parameter 'input_file1' is set
  if @api_client.config.client_side_validation && input_file1.nil?
    fail ArgumentError, "Missing the required parameter 'input_file1' when calling MergeDocumentApi.merge_document_txt"
  end
  # verify the required parameter 'input_file2' is set
  if @api_client.config.client_side_validation && input_file2.nil?
    fail ArgumentError, "Missing the required parameter 'input_file2' when calling MergeDocumentApi.merge_document_txt"
  end
  # resource path
  local_var_path = "/convert/merge/txt"

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/octet-stream'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['multipart/form-data'])

  # form parameters
  form_params = {}
  form_params["inputFile1"] = input_file1
  form_params["inputFile2"] = input_file2

  # http body (model)
  post_body = nil
  auth_names = ['Apikey']
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'Object')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: MergeDocumentApi#merge_document_txt\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#merge_document_xlsx(input_file1, input_file2, opts = {}) ⇒ String

Merge Two Excel XLSX Together Combine two Office Excel spreadsheets (xlsx) into a single Office Excel spreadsheet

Parameters:

  • input_file1

    First input file to perform the operation on.

  • input_file2

    Second input file to perform the operation on (more than 2 can be supplied).

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (String)


779
780
781
782
# File 'lib/cloudmersive-convert-api-client/api/merge_document_api.rb', line 779

def merge_document_xlsx(input_file1, input_file2, opts = {})
  data, _status_code, _headers = merge_document_xlsx_with_http_info(input_file1, input_file2, opts)
  return data
end

#merge_document_xlsx_multi(input_file1, input_file2, opts = {}) ⇒ String

Merge Multple Excel XLSX Together Combine multiple Office Excel spreadsheets (xlsx) into a single Office Excel spreadsheet

Parameters:

  • input_file1

    First input file to perform the operation on.

  • input_file2

    Second input file to perform the operation on.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :input_file3 (File)

    Third input file to perform the operation on.

  • :input_file4 (File)

    Fourth input file to perform the operation on.

  • :input_file5 (File)

    Fifth input file to perform the operation on.

  • :input_file6 (File)

    Sixth input file to perform the operation on.

  • :input_file7 (File)

    Seventh input file to perform the operation on.

  • :input_file8 (File)

    Eighth input file to perform the operation on.

  • :input_file9 (File)

    Ninth input file to perform the operation on.

  • :input_file10 (File)

    Tenth input file to perform the operation on.

Returns:

  • (String)


850
851
852
853
# File 'lib/cloudmersive-convert-api-client/api/merge_document_api.rb', line 850

def merge_document_xlsx_multi(input_file1, input_file2, opts = {})
  data, _status_code, _headers = merge_document_xlsx_multi_with_http_info(input_file1, input_file2, opts)
  return data
end

#merge_document_xlsx_multi_with_http_info(input_file1, input_file2, opts = {}) ⇒ Array<(String, Fixnum, Hash)>

Merge Multple Excel XLSX Together Combine multiple Office Excel spreadsheets (xlsx) into a single Office Excel spreadsheet

Parameters:

  • input_file1

    First input file to perform the operation on.

  • input_file2

    Second input file to perform the operation on.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :input_file3 (File)

    Third input file to perform the operation on.

  • :input_file4 (File)

    Fourth input file to perform the operation on.

  • :input_file5 (File)

    Fifth input file to perform the operation on.

  • :input_file6 (File)

    Sixth input file to perform the operation on.

  • :input_file7 (File)

    Seventh input file to perform the operation on.

  • :input_file8 (File)

    Eighth input file to perform the operation on.

  • :input_file9 (File)

    Ninth input file to perform the operation on.

  • :input_file10 (File)

    Tenth input file to perform the operation on.

Returns:

  • (Array<(String, Fixnum, Hash)>)

    String data, response status code and response headers



869
870
871
872
873
874
875
876
877
878
879
880
881
882
883
884
885
886
887
888
889
890
891
892
893
894
895
896
897
898
899
900
901
902
903
904
905
906
907
908
909
910
911
912
913
914
915
916
917
918
919
920
921
# File 'lib/cloudmersive-convert-api-client/api/merge_document_api.rb', line 869

def merge_document_xlsx_multi_with_http_info(input_file1, input_file2, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: MergeDocumentApi.merge_document_xlsx_multi ..."
  end
  # verify the required parameter 'input_file1' is set
  if @api_client.config.client_side_validation && input_file1.nil?
    fail ArgumentError, "Missing the required parameter 'input_file1' when calling MergeDocumentApi.merge_document_xlsx_multi"
  end
  # verify the required parameter 'input_file2' is set
  if @api_client.config.client_side_validation && input_file2.nil?
    fail ArgumentError, "Missing the required parameter 'input_file2' when calling MergeDocumentApi.merge_document_xlsx_multi"
  end
  # resource path
  local_var_path = "/convert/merge/xlsx/multi"

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/octet-stream'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['multipart/form-data'])

  # form parameters
  form_params = {}
  form_params["inputFile1"] = input_file1
  form_params["inputFile2"] = input_file2
  form_params["inputFile3"] = opts[:'input_file3'] if !opts[:'input_file3'].nil?
  form_params["inputFile4"] = opts[:'input_file4'] if !opts[:'input_file4'].nil?
  form_params["inputFile5"] = opts[:'input_file5'] if !opts[:'input_file5'].nil?
  form_params["inputFile6"] = opts[:'input_file6'] if !opts[:'input_file6'].nil?
  form_params["inputFile7"] = opts[:'input_file7'] if !opts[:'input_file7'].nil?
  form_params["inputFile8"] = opts[:'input_file8'] if !opts[:'input_file8'].nil?
  form_params["inputFile9"] = opts[:'input_file9'] if !opts[:'input_file9'].nil?
  form_params["inputFile10"] = opts[:'input_file10'] if !opts[:'input_file10'].nil?

  # http body (model)
  post_body = nil
  auth_names = ['Apikey']
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'String')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: MergeDocumentApi#merge_document_xlsx_multi\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#merge_document_xlsx_with_http_info(input_file1, input_file2, opts = {}) ⇒ Array<(String, Fixnum, Hash)>

Merge Two Excel XLSX Together Combine two Office Excel spreadsheets (xlsx) into a single Office Excel spreadsheet

Parameters:

  • input_file1

    First input file to perform the operation on.

  • input_file2

    Second input file to perform the operation on (more than 2 can be supplied).

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(String, Fixnum, Hash)>)

    String data, response status code and response headers



790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
826
827
828
829
830
831
832
833
834
# File 'lib/cloudmersive-convert-api-client/api/merge_document_api.rb', line 790

def merge_document_xlsx_with_http_info(input_file1, input_file2, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: MergeDocumentApi.merge_document_xlsx ..."
  end
  # verify the required parameter 'input_file1' is set
  if @api_client.config.client_side_validation && input_file1.nil?
    fail ArgumentError, "Missing the required parameter 'input_file1' when calling MergeDocumentApi.merge_document_xlsx"
  end
  # verify the required parameter 'input_file2' is set
  if @api_client.config.client_side_validation && input_file2.nil?
    fail ArgumentError, "Missing the required parameter 'input_file2' when calling MergeDocumentApi.merge_document_xlsx"
  end
  # resource path
  local_var_path = "/convert/merge/xlsx"

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/octet-stream'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['multipart/form-data'])

  # form parameters
  form_params = {}
  form_params["inputFile1"] = input_file1
  form_params["inputFile2"] = input_file2

  # http body (model)
  post_body = nil
  auth_names = ['Apikey']
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'String')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: MergeDocumentApi#merge_document_xlsx\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end