Class: CloudmersiveConvertApiClient::SplitDocumentApi

Inherits:
Object
  • Object
show all
Defined in:
lib/cloudmersive-convert-api-client/api/split_document_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ SplitDocumentApi



19
20
21
# File 'lib/cloudmersive-convert-api-client/api/split_document_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/cloudmersive-convert-api-client/api/split_document_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#split_document_docx(input_file, opts = {}) ⇒ SplitDocxDocumentResult

Split a single Word Document DOCX into Separate Documents by Page Split a Word DOCX Document, comprised of multiple pages into separate Word DOCX document files, with each containing exactly one page.

Options Hash (opts):

  • :return_document_contents (BOOLEAN)

    Set to true to return the contents of each Worksheet directly, set to false to only return URLs to each resulting document. Default is true.



28
29
30
31
# File 'lib/cloudmersive-convert-api-client/api/split_document_api.rb', line 28

def split_document_docx(input_file, opts = {})
  data, _status_code, _headers = split_document_docx_with_http_info(input_file, opts)
  data
end

#split_document_docx_with_http_info(input_file, opts = {}) ⇒ Array<(SplitDocxDocumentResult, Fixnum, Hash)>

Split a single Word Document DOCX into Separate Documents by Page Split a Word DOCX Document, comprised of multiple pages into separate Word DOCX document files, with each containing exactly one page.

Options Hash (opts):

  • :return_document_contents (BOOLEAN)

    Set to true to return the contents of each Worksheet directly, set to false to only return URLs to each resulting document. Default is true.



39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/cloudmersive-convert-api-client/api/split_document_api.rb', line 39

def split_document_docx_with_http_info(input_file, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: SplitDocumentApi.split_document_docx ...'
  end
  # verify the required parameter 'input_file' is set
  if @api_client.config.client_side_validation && input_file.nil?
    fail ArgumentError, "Missing the required parameter 'input_file' when calling SplitDocumentApi.split_document_docx"
  end
  # resource path
  local_var_path = '/convert/split/docx'

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json', 'text/json', 'application/xml', 'text/xml'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['multipart/form-data'])
  header_params[:'returnDocumentContents'] = opts[:'return_document_contents'] if !opts[:'return_document_contents'].nil?

  # form parameters
  form_params = {}
  form_params['inputFile'] = input_file

  # http body (model)
  post_body = nil
  auth_names = ['Apikey']
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'SplitDocxDocumentResult')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: SplitDocumentApi#split_document_docx\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#split_document_pdf_by_page(input_file, opts = {}) ⇒ SplitPdfResult

Split a PDF file into separate PDF files, one per page Split an input PDF file into separate pages, comprised of one PDF file per page.

Options Hash (opts):

  • :return_document_contents (BOOLEAN)

    Set to true to directly return all of the document contents in the DocumentContents field; set to false to return contents as temporary URLs (more efficient for large operations). Default is false.



86
87
88
89
# File 'lib/cloudmersive-convert-api-client/api/split_document_api.rb', line 86

def split_document_pdf_by_page(input_file, opts = {})
  data, _status_code, _headers = split_document_pdf_by_page_with_http_info(input_file, opts)
  data
end

#split_document_pdf_by_page_with_http_info(input_file, opts = {}) ⇒ Array<(SplitPdfResult, Fixnum, Hash)>

Split a PDF file into separate PDF files, one per page Split an input PDF file into separate pages, comprised of one PDF file per page.

Options Hash (opts):

  • :return_document_contents (BOOLEAN)

    Set to true to directly return all of the document contents in the DocumentContents field; set to false to return contents as temporary URLs (more efficient for large operations). Default is false.



97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
# File 'lib/cloudmersive-convert-api-client/api/split_document_api.rb', line 97

def split_document_pdf_by_page_with_http_info(input_file, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: SplitDocumentApi.split_document_pdf_by_page ...'
  end
  # verify the required parameter 'input_file' is set
  if @api_client.config.client_side_validation && input_file.nil?
    fail ArgumentError, "Missing the required parameter 'input_file' when calling SplitDocumentApi.split_document_pdf_by_page"
  end
  # resource path
  local_var_path = '/convert/split/pdf'

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json', 'text/json', 'application/xml', 'text/xml'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['multipart/form-data'])
  header_params[:'returnDocumentContents'] = opts[:'return_document_contents'] if !opts[:'return_document_contents'].nil?

  # form parameters
  form_params = {}
  form_params['inputFile'] = input_file

  # http body (model)
  post_body = nil
  auth_names = ['Apikey']
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'SplitPdfResult')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: SplitDocumentApi#split_document_pdf_by_page\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#split_document_pptx(input_file, opts = {}) ⇒ SplitPptxPresentationResult

Split a single PowerPoint Presentation PPTX into Separate Slides Split an PowerPoint PPTX Presentation, comprised of multiple slides into separate PowerPoint PPTX presentation files, with each containing exactly one slide.

Options Hash (opts):

  • :return_document_contents (BOOLEAN)

    Set to true to return the contents of each presentation directly, set to false to only return URLs to each resulting presentation. Default is true.



144
145
146
147
# File 'lib/cloudmersive-convert-api-client/api/split_document_api.rb', line 144

def split_document_pptx(input_file, opts = {})
  data, _status_code, _headers = split_document_pptx_with_http_info(input_file, opts)
  data
end

#split_document_pptx_with_http_info(input_file, opts = {}) ⇒ Array<(SplitPptxPresentationResult, Fixnum, Hash)>

Split a single PowerPoint Presentation PPTX into Separate Slides Split an PowerPoint PPTX Presentation, comprised of multiple slides into separate PowerPoint PPTX presentation files, with each containing exactly one slide.

Options Hash (opts):

  • :return_document_contents (BOOLEAN)

    Set to true to return the contents of each presentation directly, set to false to only return URLs to each resulting presentation. Default is true.



155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/cloudmersive-convert-api-client/api/split_document_api.rb', line 155

def split_document_pptx_with_http_info(input_file, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: SplitDocumentApi.split_document_pptx ...'
  end
  # verify the required parameter 'input_file' is set
  if @api_client.config.client_side_validation && input_file.nil?
    fail ArgumentError, "Missing the required parameter 'input_file' when calling SplitDocumentApi.split_document_pptx"
  end
  # resource path
  local_var_path = '/convert/split/pptx'

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json', 'text/json', 'application/xml', 'text/xml'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['multipart/form-data'])
  header_params[:'returnDocumentContents'] = opts[:'return_document_contents'] if !opts[:'return_document_contents'].nil?

  # form parameters
  form_params = {}
  form_params['inputFile'] = input_file

  # http body (model)
  post_body = nil
  auth_names = ['Apikey']
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'SplitPptxPresentationResult')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: SplitDocumentApi#split_document_pptx\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#split_document_txt_by_line(input_file, opts = {}) ⇒ SplitTextDocumentByLinesResult

Split a single Text file (txt) into lines Split a Text (txt) Document by line, returning each line separately in order. Supports multiple types of newlines.



201
202
203
204
# File 'lib/cloudmersive-convert-api-client/api/split_document_api.rb', line 201

def (input_file, opts = {})
  data, _status_code, _headers = (input_file, opts)
  data
end

#split_document_txt_by_line_with_http_info(input_file, opts = {}) ⇒ Array<(SplitTextDocumentByLinesResult, Fixnum, Hash)>

Split a single Text file (txt) into lines Split a Text (txt) Document by line, returning each line separately in order. Supports multiple types of newlines.



211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
# File 'lib/cloudmersive-convert-api-client/api/split_document_api.rb', line 211

def (input_file, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: SplitDocumentApi.split_document_txt_by_line ...'
  end
  # verify the required parameter 'input_file' is set
  if @api_client.config.client_side_validation && input_file.nil?
    fail ArgumentError, "Missing the required parameter 'input_file' when calling SplitDocumentApi.split_document_txt_by_line"
  end
  # resource path
  local_var_path = '/convert/split/txt/by-line'

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json', 'text/json', 'application/xml', 'text/xml'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['multipart/form-data'])

  # form parameters
  form_params = {}
  form_params['inputFile'] = input_file

  # http body (model)
  post_body = nil
  auth_names = ['Apikey']
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'SplitTextDocumentByLinesResult')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: SplitDocumentApi#split_document_txt_by_line\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#split_document_txt_by_string(input_file, split_delimiter, opts = {}) ⇒ SplitTextDocumentByStringResult

Split a single Text file (txt) by a string delimiter Split a Text (txt) Document by a string delimiter, returning each component of the string as an array of strings.

Options Hash (opts):

  • :skip_empty_elements (BOOLEAN)

    Optional; If true, empty elements will be skipped in the output



258
259
260
261
# File 'lib/cloudmersive-convert-api-client/api/split_document_api.rb', line 258

def split_document_txt_by_string(input_file, split_delimiter, opts = {})
  data, _status_code, _headers = split_document_txt_by_string_with_http_info(input_file, split_delimiter, opts)
  data
end

#split_document_txt_by_string_with_http_info(input_file, split_delimiter, opts = {}) ⇒ Array<(SplitTextDocumentByStringResult, Fixnum, Hash)>

Split a single Text file (txt) by a string delimiter Split a Text (txt) Document by a string delimiter, returning each component of the string as an array of strings.

Options Hash (opts):

  • :skip_empty_elements (BOOLEAN)

    Optional; If true, empty elements will be skipped in the output



270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
# File 'lib/cloudmersive-convert-api-client/api/split_document_api.rb', line 270

def split_document_txt_by_string_with_http_info(input_file, split_delimiter, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: SplitDocumentApi.split_document_txt_by_string ...'
  end
  # verify the required parameter 'input_file' is set
  if @api_client.config.client_side_validation && input_file.nil?
    fail ArgumentError, "Missing the required parameter 'input_file' when calling SplitDocumentApi.split_document_txt_by_string"
  end
  # verify the required parameter 'split_delimiter' is set
  if @api_client.config.client_side_validation && split_delimiter.nil?
    fail ArgumentError, "Missing the required parameter 'split_delimiter' when calling SplitDocumentApi.split_document_txt_by_string"
  end
  # resource path
  local_var_path = '/convert/split/txt/by-string'

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json', 'text/json', 'application/xml', 'text/xml'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['multipart/form-data'])
  header_params[:'splitDelimiter'] = split_delimiter
  header_params[:'skipEmptyElements'] = opts[:'skip_empty_elements'] if !opts[:'skip_empty_elements'].nil?

  # form parameters
  form_params = {}
  form_params['inputFile'] = input_file

  # http body (model)
  post_body = nil
  auth_names = ['Apikey']
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'SplitTextDocumentByStringResult')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: SplitDocumentApi#split_document_txt_by_string\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#split_document_xlsx(input_file, opts = {}) ⇒ SplitXlsxWorksheetResult

Split a single Excel XLSX into Separate Worksheets Split an Excel XLSX Spreadsheet, comprised of multiple Worksheets (or Tabs) into separate Excel XLSX spreadsheet files, with each containing exactly one Worksheet.

Options Hash (opts):

  • :return_document_contents (BOOLEAN)

    Set to true to return the contents of each Worksheet directly, set to false to only return URLs to each resulting worksheet. Default is true.



322
323
324
325
# File 'lib/cloudmersive-convert-api-client/api/split_document_api.rb', line 322

def split_document_xlsx(input_file, opts = {})
  data, _status_code, _headers = split_document_xlsx_with_http_info(input_file, opts)
  data
end

#split_document_xlsx_with_http_info(input_file, opts = {}) ⇒ Array<(SplitXlsxWorksheetResult, Fixnum, Hash)>

Split a single Excel XLSX into Separate Worksheets Split an Excel XLSX Spreadsheet, comprised of multiple Worksheets (or Tabs) into separate Excel XLSX spreadsheet files, with each containing exactly one Worksheet.

Options Hash (opts):

  • :return_document_contents (BOOLEAN)

    Set to true to return the contents of each Worksheet directly, set to false to only return URLs to each resulting worksheet. Default is true.



333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
# File 'lib/cloudmersive-convert-api-client/api/split_document_api.rb', line 333

def split_document_xlsx_with_http_info(input_file, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: SplitDocumentApi.split_document_xlsx ...'
  end
  # verify the required parameter 'input_file' is set
  if @api_client.config.client_side_validation && input_file.nil?
    fail ArgumentError, "Missing the required parameter 'input_file' when calling SplitDocumentApi.split_document_xlsx"
  end
  # resource path
  local_var_path = '/convert/split/xlsx'

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json', 'text/json', 'application/xml', 'text/xml'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['multipart/form-data'])
  header_params[:'returnDocumentContents'] = opts[:'return_document_contents'] if !opts[:'return_document_contents'].nil?

  # form parameters
  form_params = {}
  form_params['inputFile'] = input_file

  # http body (model)
  post_body = nil
  auth_names = ['Apikey']
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'SplitXlsxWorksheetResult')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: SplitDocumentApi#split_document_xlsx\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end