Class: CloudmersiveConvertApiClient::ValidateDocumentApi
- Inherits:
-
Object
- Object
- CloudmersiveConvertApiClient::ValidateDocumentApi
- Defined in:
- lib/cloudmersive-convert-api-client/api/validate_document_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ ValidateDocumentApi
constructor
A new instance of ValidateDocumentApi.
-
#validate_document_autodetect_validation(input_file, opts = {}) ⇒ AutodetectDocumentValidationResult
Autodetect content type and validate Automatically detect the type of content, verify and validate that the content is indeed fully valid at depth, and then report the validation result.
-
#validate_document_autodetect_validation_with_http_info(input_file, opts = {}) ⇒ Array<(AutodetectDocumentValidationResult, Fixnum, Hash)>
Autodetect content type and validate Automatically detect the type of content, verify and validate that the content is indeed fully valid at depth, and then report the validation result.
-
#validate_document_csv_validation(input_file, opts = {}) ⇒ DocumentValidationResult
Validate a CSV file document (CSV) Validate a CSV file document (CSV); if the document is not valid, identifies the errors in the document.
-
#validate_document_csv_validation_with_http_info(input_file, opts = {}) ⇒ Array<(DocumentValidationResult, Fixnum, Hash)>
Validate a CSV file document (CSV) Validate a CSV file document (CSV); if the document is not valid, identifies the errors in the document.
-
#validate_document_docx_validation(input_file, opts = {}) ⇒ DocumentValidationResult
Validate a Word document (DOCX) Validate a Word document (DOCX); if the document is not valid, identifies the errors in the document.
-
#validate_document_docx_validation_with_http_info(input_file, opts = {}) ⇒ Array<(DocumentValidationResult, Fixnum, Hash)>
Validate a Word document (DOCX) Validate a Word document (DOCX); if the document is not valid, identifies the errors in the document.
-
#validate_document_eml_validation(input_file, opts = {}) ⇒ DocumentValidationResult
Validate if an EML file is executable Validate if an input file is an EML email file; if the document is not valid.
-
#validate_document_eml_validation_with_http_info(input_file, opts = {}) ⇒ Array<(DocumentValidationResult, Fixnum, Hash)>
Validate if an EML file is executable Validate if an input file is an EML email file; if the document is not valid.
-
#validate_document_executable_validation(input_file, opts = {}) ⇒ DocumentValidationResult
Validate if a file is executable Validate if an input file is a binary executable file; if the document is not valid.
-
#validate_document_executable_validation_with_http_info(input_file, opts = {}) ⇒ Array<(DocumentValidationResult, Fixnum, Hash)>
Validate if a file is executable Validate if an input file is a binary executable file; if the document is not valid.
-
#validate_document_g_zip_validation(input_file, opts = {}) ⇒ DocumentValidationResult
Validate a GZip Archive file (gzip or gz) Validate a GZip archive file (GZIP or GZ).
-
#validate_document_g_zip_validation_with_http_info(input_file, opts = {}) ⇒ Array<(DocumentValidationResult, Fixnum, Hash)>
Validate a GZip Archive file (gzip or gz) Validate a GZip archive file (GZIP or GZ).
-
#validate_document_html_validation(input_file, opts = {}) ⇒ DocumentValidationResult
Validate an HTML file Validate an HTML document file; if the document is not valid, identifies the errors in the document.
-
#validate_document_html_validation_with_http_info(input_file, opts = {}) ⇒ Array<(DocumentValidationResult, Fixnum, Hash)>
Validate an HTML file Validate an HTML document file; if the document is not valid, identifies the errors in the document.
-
#validate_document_image_validation(input_file, opts = {}) ⇒ DocumentValidationResult
Validate an Image File Validate an image file; if the document is not valid, identifies the errors in the document.
-
#validate_document_image_validation_with_http_info(input_file, opts = {}) ⇒ Array<(DocumentValidationResult, Fixnum, Hash)>
Validate an Image File Validate an image file; if the document is not valid, identifies the errors in the document.
-
#validate_document_json_validation(input_file, opts = {}) ⇒ DocumentValidationResult
Validate a JSON file Validate a JSON (JavaScript Object Notation) document file; if the document is not valid, identifies the errors in the document.
-
#validate_document_json_validation_with_http_info(input_file, opts = {}) ⇒ Array<(DocumentValidationResult, Fixnum, Hash)>
Validate a JSON file Validate a JSON (JavaScript Object Notation) document file; if the document is not valid, identifies the errors in the document.
-
#validate_document_msg_validation(input_file, opts = {}) ⇒ DocumentValidationResult
Validate if an MSG file is executable Validate if an input file is an MSG email file; if the document is not valid.
-
#validate_document_msg_validation_with_http_info(input_file, opts = {}) ⇒ Array<(DocumentValidationResult, Fixnum, Hash)>
Validate if an MSG file is executable Validate if an input file is an MSG email file; if the document is not valid.
-
#validate_document_pdf_validation(input_file, opts = {}) ⇒ DocumentValidationResult
Validate a PDF document file Validate a PDF document; if the document is not valid, identifies the errors in the document.
-
#validate_document_pdf_validation_with_http_info(input_file, opts = {}) ⇒ Array<(DocumentValidationResult, Fixnum, Hash)>
Validate a PDF document file Validate a PDF document; if the document is not valid, identifies the errors in the document.
-
#validate_document_pptx_validation(input_file, opts = {}) ⇒ DocumentValidationResult
Validate a PowerPoint presentation (PPTX) Validate a PowerPoint presentation (PPTX); if the document is not valid, identifies the errors in the document.
-
#validate_document_pptx_validation_with_http_info(input_file, opts = {}) ⇒ Array<(DocumentValidationResult, Fixnum, Hash)>
Validate a PowerPoint presentation (PPTX) Validate a PowerPoint presentation (PPTX); if the document is not valid, identifies the errors in the document.
-
#validate_document_rar_validation(input_file, opts = {}) ⇒ DocumentValidationResult
Validate a RAR Archive file (RAR) Validate a RAR archive file (RAR).
-
#validate_document_rar_validation_with_http_info(input_file, opts = {}) ⇒ Array<(DocumentValidationResult, Fixnum, Hash)>
Validate a RAR Archive file (RAR) Validate a RAR archive file (RAR).
-
#validate_document_tar_validation(input_file, opts = {}) ⇒ DocumentValidationResult
Validate a TAR Tarball Archive file (TAR) Validate a TAR tarball archive file (TAR).
-
#validate_document_tar_validation_with_http_info(input_file, opts = {}) ⇒ Array<(DocumentValidationResult, Fixnum, Hash)>
Validate a TAR Tarball Archive file (TAR) Validate a TAR tarball archive file (TAR).
-
#validate_document_xlsx_validation(input_file, opts = {}) ⇒ DocumentValidationResult
Validate a Excel document (XLSX) Validate a Excel document (XLSX); if the document is not valid, identifies the errors in the document.
-
#validate_document_xlsx_validation_with_http_info(input_file, opts = {}) ⇒ Array<(DocumentValidationResult, Fixnum, Hash)>
Validate a Excel document (XLSX) Validate a Excel document (XLSX); if the document is not valid, identifies the errors in the document.
-
#validate_document_xml_validation(input_file, opts = {}) ⇒ DocumentValidationResult
Validate an XML file Validate an XML document file; if the document is not valid, identifies the errors in the document.
-
#validate_document_xml_validation_with_http_info(input_file, opts = {}) ⇒ Array<(DocumentValidationResult, Fixnum, Hash)>
Validate an XML file Validate an XML document file; if the document is not valid, identifies the errors in the document.
-
#validate_document_zip_validation(input_file, opts = {}) ⇒ DocumentValidationResult
Validate a Zip Archive file (zip) Validate a Zip archive file (ZIP).
-
#validate_document_zip_validation_with_http_info(input_file, opts = {}) ⇒ Array<(DocumentValidationResult, Fixnum, Hash)>
Validate a Zip Archive file (zip) Validate a Zip archive file (ZIP).
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ ValidateDocumentApi
Returns a new instance of ValidateDocumentApi.
19 20 21 |
# File 'lib/cloudmersive-convert-api-client/api/validate_document_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/cloudmersive-convert-api-client/api/validate_document_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#validate_document_autodetect_validation(input_file, opts = {}) ⇒ AutodetectDocumentValidationResult
Autodetect content type and validate Automatically detect the type of content, verify and validate that the content is indeed fully valid at depth, and then report the validation result.
27 28 29 30 |
# File 'lib/cloudmersive-convert-api-client/api/validate_document_api.rb', line 27 def validate_document_autodetect_validation(input_file, opts = {}) data, _status_code, _headers = validate_document_autodetect_validation_with_http_info(input_file, opts) data end |
#validate_document_autodetect_validation_with_http_info(input_file, opts = {}) ⇒ Array<(AutodetectDocumentValidationResult, Fixnum, Hash)>
Autodetect content type and validate Automatically detect the type of content, verify and validate that the content is indeed fully valid at depth, and then report the validation result.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/cloudmersive-convert-api-client/api/validate_document_api.rb', line 37 def validate_document_autodetect_validation_with_http_info(input_file, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ValidateDocumentApi.validate_document_autodetect_validation ...' end # verify the required parameter 'input_file' is set if @api_client.config.client_side_validation && input_file.nil? fail ArgumentError, "Missing the required parameter 'input_file' when calling ValidateDocumentApi.validate_document_autodetect_validation" end # resource path local_var_path = '/convert/validate/autodetect' # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json', 'text/json', 'application/xml', 'text/xml']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['multipart/form-data']) # form parameters form_params = {} form_params['inputFile'] = input_file # http body (model) post_body = nil auth_names = ['Apikey'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'AutodetectDocumentValidationResult') if @api_client.config.debugging @api_client.config.logger.debug "API called: ValidateDocumentApi#validate_document_autodetect_validation\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#validate_document_csv_validation(input_file, opts = {}) ⇒ DocumentValidationResult
Validate a CSV file document (CSV) Validate a CSV file document (CSV); if the document is not valid, identifies the errors in the document
82 83 84 85 |
# File 'lib/cloudmersive-convert-api-client/api/validate_document_api.rb', line 82 def validate_document_csv_validation(input_file, opts = {}) data, _status_code, _headers = validate_document_csv_validation_with_http_info(input_file, opts) data end |
#validate_document_csv_validation_with_http_info(input_file, opts = {}) ⇒ Array<(DocumentValidationResult, Fixnum, Hash)>
Validate a CSV file document (CSV) Validate a CSV file document (CSV); if the document is not valid, identifies the errors in the document
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 |
# File 'lib/cloudmersive-convert-api-client/api/validate_document_api.rb', line 92 def validate_document_csv_validation_with_http_info(input_file, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ValidateDocumentApi.validate_document_csv_validation ...' end # verify the required parameter 'input_file' is set if @api_client.config.client_side_validation && input_file.nil? fail ArgumentError, "Missing the required parameter 'input_file' when calling ValidateDocumentApi.validate_document_csv_validation" end # resource path local_var_path = '/convert/validate/csv' # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json', 'text/json', 'application/xml', 'text/xml']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['multipart/form-data']) # form parameters form_params = {} form_params['inputFile'] = input_file # http body (model) post_body = nil auth_names = ['Apikey'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'DocumentValidationResult') if @api_client.config.debugging @api_client.config.logger.debug "API called: ValidateDocumentApi#validate_document_csv_validation\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#validate_document_docx_validation(input_file, opts = {}) ⇒ DocumentValidationResult
Validate a Word document (DOCX) Validate a Word document (DOCX); if the document is not valid, identifies the errors in the document
137 138 139 140 |
# File 'lib/cloudmersive-convert-api-client/api/validate_document_api.rb', line 137 def validate_document_docx_validation(input_file, opts = {}) data, _status_code, _headers = validate_document_docx_validation_with_http_info(input_file, opts) data end |
#validate_document_docx_validation_with_http_info(input_file, opts = {}) ⇒ Array<(DocumentValidationResult, Fixnum, Hash)>
Validate a Word document (DOCX) Validate a Word document (DOCX); if the document is not valid, identifies the errors in the document
147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 |
# File 'lib/cloudmersive-convert-api-client/api/validate_document_api.rb', line 147 def validate_document_docx_validation_with_http_info(input_file, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ValidateDocumentApi.validate_document_docx_validation ...' end # verify the required parameter 'input_file' is set if @api_client.config.client_side_validation && input_file.nil? fail ArgumentError, "Missing the required parameter 'input_file' when calling ValidateDocumentApi.validate_document_docx_validation" end # resource path local_var_path = '/convert/validate/docx' # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json', 'text/json', 'application/xml', 'text/xml']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['multipart/form-data']) # form parameters form_params = {} form_params['inputFile'] = input_file # http body (model) post_body = nil auth_names = ['Apikey'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'DocumentValidationResult') if @api_client.config.debugging @api_client.config.logger.debug "API called: ValidateDocumentApi#validate_document_docx_validation\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#validate_document_eml_validation(input_file, opts = {}) ⇒ DocumentValidationResult
Validate if an EML file is executable Validate if an input file is an EML email file; if the document is not valid
192 193 194 195 |
# File 'lib/cloudmersive-convert-api-client/api/validate_document_api.rb', line 192 def validate_document_eml_validation(input_file, opts = {}) data, _status_code, _headers = validate_document_eml_validation_with_http_info(input_file, opts) data end |
#validate_document_eml_validation_with_http_info(input_file, opts = {}) ⇒ Array<(DocumentValidationResult, Fixnum, Hash)>
Validate if an EML file is executable Validate if an input file is an EML email file; if the document is not valid
202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 |
# File 'lib/cloudmersive-convert-api-client/api/validate_document_api.rb', line 202 def validate_document_eml_validation_with_http_info(input_file, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ValidateDocumentApi.validate_document_eml_validation ...' end # verify the required parameter 'input_file' is set if @api_client.config.client_side_validation && input_file.nil? fail ArgumentError, "Missing the required parameter 'input_file' when calling ValidateDocumentApi.validate_document_eml_validation" end # resource path local_var_path = '/convert/validate/eml' # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json', 'text/json', 'application/xml', 'text/xml']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['multipart/form-data']) # form parameters form_params = {} form_params['inputFile'] = input_file # http body (model) post_body = nil auth_names = ['Apikey'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'DocumentValidationResult') if @api_client.config.debugging @api_client.config.logger.debug "API called: ValidateDocumentApi#validate_document_eml_validation\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#validate_document_executable_validation(input_file, opts = {}) ⇒ DocumentValidationResult
Validate if a file is executable Validate if an input file is a binary executable file; if the document is not valid
247 248 249 250 |
# File 'lib/cloudmersive-convert-api-client/api/validate_document_api.rb', line 247 def validate_document_executable_validation(input_file, opts = {}) data, _status_code, _headers = validate_document_executable_validation_with_http_info(input_file, opts) data end |
#validate_document_executable_validation_with_http_info(input_file, opts = {}) ⇒ Array<(DocumentValidationResult, Fixnum, Hash)>
Validate if a file is executable Validate if an input file is a binary executable file; if the document is not valid
257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 |
# File 'lib/cloudmersive-convert-api-client/api/validate_document_api.rb', line 257 def validate_document_executable_validation_with_http_info(input_file, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ValidateDocumentApi.validate_document_executable_validation ...' end # verify the required parameter 'input_file' is set if @api_client.config.client_side_validation && input_file.nil? fail ArgumentError, "Missing the required parameter 'input_file' when calling ValidateDocumentApi.validate_document_executable_validation" end # resource path local_var_path = '/convert/validate/executable' # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json', 'text/json', 'application/xml', 'text/xml']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['multipart/form-data']) # form parameters form_params = {} form_params['inputFile'] = input_file # http body (model) post_body = nil auth_names = ['Apikey'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'DocumentValidationResult') if @api_client.config.debugging @api_client.config.logger.debug "API called: ValidateDocumentApi#validate_document_executable_validation\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#validate_document_g_zip_validation(input_file, opts = {}) ⇒ DocumentValidationResult
Validate a GZip Archive file (gzip or gz) Validate a GZip archive file (GZIP or GZ)
302 303 304 305 |
# File 'lib/cloudmersive-convert-api-client/api/validate_document_api.rb', line 302 def validate_document_g_zip_validation(input_file, opts = {}) data, _status_code, _headers = validate_document_g_zip_validation_with_http_info(input_file, opts) data end |
#validate_document_g_zip_validation_with_http_info(input_file, opts = {}) ⇒ Array<(DocumentValidationResult, Fixnum, Hash)>
Validate a GZip Archive file (gzip or gz) Validate a GZip archive file (GZIP or GZ)
312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 |
# File 'lib/cloudmersive-convert-api-client/api/validate_document_api.rb', line 312 def validate_document_g_zip_validation_with_http_info(input_file, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ValidateDocumentApi.validate_document_g_zip_validation ...' end # verify the required parameter 'input_file' is set if @api_client.config.client_side_validation && input_file.nil? fail ArgumentError, "Missing the required parameter 'input_file' when calling ValidateDocumentApi.validate_document_g_zip_validation" end # resource path local_var_path = '/convert/validate/gzip' # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json', 'text/json', 'application/xml', 'text/xml']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['multipart/form-data']) # form parameters form_params = {} form_params['inputFile'] = input_file # http body (model) post_body = nil auth_names = ['Apikey'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'DocumentValidationResult') if @api_client.config.debugging @api_client.config.logger.debug "API called: ValidateDocumentApi#validate_document_g_zip_validation\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#validate_document_html_validation(input_file, opts = {}) ⇒ DocumentValidationResult
Validate an HTML file Validate an HTML document file; if the document is not valid, identifies the errors in the document
357 358 359 360 |
# File 'lib/cloudmersive-convert-api-client/api/validate_document_api.rb', line 357 def validate_document_html_validation(input_file, opts = {}) data, _status_code, _headers = validate_document_html_validation_with_http_info(input_file, opts) data end |
#validate_document_html_validation_with_http_info(input_file, opts = {}) ⇒ Array<(DocumentValidationResult, Fixnum, Hash)>
Validate an HTML file Validate an HTML document file; if the document is not valid, identifies the errors in the document
367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 |
# File 'lib/cloudmersive-convert-api-client/api/validate_document_api.rb', line 367 def validate_document_html_validation_with_http_info(input_file, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ValidateDocumentApi.validate_document_html_validation ...' end # verify the required parameter 'input_file' is set if @api_client.config.client_side_validation && input_file.nil? fail ArgumentError, "Missing the required parameter 'input_file' when calling ValidateDocumentApi.validate_document_html_validation" end # resource path local_var_path = '/convert/validate/html' # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json', 'text/json', 'application/xml', 'text/xml']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['multipart/form-data']) # form parameters form_params = {} form_params['inputFile'] = input_file # http body (model) post_body = nil auth_names = ['Apikey'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'DocumentValidationResult') if @api_client.config.debugging @api_client.config.logger.debug "API called: ValidateDocumentApi#validate_document_html_validation\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#validate_document_image_validation(input_file, opts = {}) ⇒ DocumentValidationResult
Validate an Image File Validate an image file; if the document is not valid, identifies the errors in the document. Formats supported include AAI, ART, ARW, AVS, BPG, BMP, BMP2, BMP3, BRF, CALS, CGM, CIN, CMYK, CMYKA, CR2, CRW, CUR, CUT, DCM, DCR, DCX, DDS, DIB, DJVU, DNG, DOT, DPX, EMF, EPDF, EPI, EPS, EPS2, EPS3, EPSF, EPSI, EPT, EXR, FAX, FIG, FITS, FPX, GIF, GPLT, GRAY, HDR, HEIC, HPGL, HRZ, ICO, ISOBRL, ISBRL6, JBIG, JNG, JP2, JPT, J2C, J2K, JPEG/JPG, JXR, MAT, MONO, MNG, M2V, MRW, MTV, NEF, ORF, OTB, P7, PALM, PAM, PBM, PCD, PCDS, PCL, PCX, PDF, PEF, PES, PFA, PFB, PFM, PGM, PICON, PICT, PIX, PNG, PNG8, PNG00, PNG24, PNG32, PNG48, PNG64, PNM, PPM, PSB, PSD, PTIF, PWB, RAD, RAF, RGB, RGBA, RGF, RLA, RLE, SCT, SFW, SGI, SID, SUN, SVG, TGA, TIFF, TIM, UIL, VIFF, VICAR, VBMP, WDP, WEBP, WPG, X, XBM, XCF, XPM, XWD, X3F, YCbCr, YCbCrA, YUV.
412 413 414 415 |
# File 'lib/cloudmersive-convert-api-client/api/validate_document_api.rb', line 412 def validate_document_image_validation(input_file, opts = {}) data, _status_code, _headers = validate_document_image_validation_with_http_info(input_file, opts) data end |
#validate_document_image_validation_with_http_info(input_file, opts = {}) ⇒ Array<(DocumentValidationResult, Fixnum, Hash)>
Validate an Image File Validate an image file; if the document is not valid, identifies the errors in the document. Formats supported include AAI, ART, ARW, AVS, BPG, BMP, BMP2, BMP3, BRF, CALS, CGM, CIN, CMYK, CMYKA, CR2, CRW, CUR, CUT, DCM, DCR, DCX, DDS, DIB, DJVU, DNG, DOT, DPX, EMF, EPDF, EPI, EPS, EPS2, EPS3, EPSF, EPSI, EPT, EXR, FAX, FIG, FITS, FPX, GIF, GPLT, GRAY, HDR, HEIC, HPGL, HRZ, ICO, ISOBRL, ISBRL6, JBIG, JNG, JP2, JPT, J2C, J2K, JPEG/JPG, JXR, MAT, MONO, MNG, M2V, MRW, MTV, NEF, ORF, OTB, P7, PALM, PAM, PBM, PCD, PCDS, PCL, PCX, PDF, PEF, PES, PFA, PFB, PFM, PGM, PICON, PICT, PIX, PNG, PNG8, PNG00, PNG24, PNG32, PNG48, PNG64, PNM, PPM, PSB, PSD, PTIF, PWB, RAD, RAF, RGB, RGBA, RGF, RLA, RLE, SCT, SFW, SGI, SID, SUN, SVG, TGA, TIFF, TIM, UIL, VIFF, VICAR, VBMP, WDP, WEBP, WPG, X, XBM, XCF, XPM, XWD, X3F, YCbCr, YCbCrA, YUV.
422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 |
# File 'lib/cloudmersive-convert-api-client/api/validate_document_api.rb', line 422 def validate_document_image_validation_with_http_info(input_file, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ValidateDocumentApi.validate_document_image_validation ...' end # verify the required parameter 'input_file' is set if @api_client.config.client_side_validation && input_file.nil? fail ArgumentError, "Missing the required parameter 'input_file' when calling ValidateDocumentApi.validate_document_image_validation" end # resource path local_var_path = '/convert/validate/image' # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json', 'text/json', 'application/xml', 'text/xml']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['multipart/form-data']) # form parameters form_params = {} form_params['inputFile'] = input_file # http body (model) post_body = nil auth_names = ['Apikey'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'DocumentValidationResult') if @api_client.config.debugging @api_client.config.logger.debug "API called: ValidateDocumentApi#validate_document_image_validation\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#validate_document_json_validation(input_file, opts = {}) ⇒ DocumentValidationResult
Validate a JSON file Validate a JSON (JavaScript Object Notation) document file; if the document is not valid, identifies the errors in the document
467 468 469 470 |
# File 'lib/cloudmersive-convert-api-client/api/validate_document_api.rb', line 467 def validate_document_json_validation(input_file, opts = {}) data, _status_code, _headers = validate_document_json_validation_with_http_info(input_file, opts) data end |
#validate_document_json_validation_with_http_info(input_file, opts = {}) ⇒ Array<(DocumentValidationResult, Fixnum, Hash)>
Validate a JSON file Validate a JSON (JavaScript Object Notation) document file; if the document is not valid, identifies the errors in the document
477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 |
# File 'lib/cloudmersive-convert-api-client/api/validate_document_api.rb', line 477 def validate_document_json_validation_with_http_info(input_file, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ValidateDocumentApi.validate_document_json_validation ...' end # verify the required parameter 'input_file' is set if @api_client.config.client_side_validation && input_file.nil? fail ArgumentError, "Missing the required parameter 'input_file' when calling ValidateDocumentApi.validate_document_json_validation" end # resource path local_var_path = '/convert/validate/json' # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json', 'text/json', 'application/xml', 'text/xml']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['multipart/form-data']) # form parameters form_params = {} form_params['inputFile'] = input_file # http body (model) post_body = nil auth_names = ['Apikey'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'DocumentValidationResult') if @api_client.config.debugging @api_client.config.logger.debug "API called: ValidateDocumentApi#validate_document_json_validation\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#validate_document_msg_validation(input_file, opts = {}) ⇒ DocumentValidationResult
Validate if an MSG file is executable Validate if an input file is an MSG email file; if the document is not valid
522 523 524 525 |
# File 'lib/cloudmersive-convert-api-client/api/validate_document_api.rb', line 522 def validate_document_msg_validation(input_file, opts = {}) data, _status_code, _headers = validate_document_msg_validation_with_http_info(input_file, opts) data end |
#validate_document_msg_validation_with_http_info(input_file, opts = {}) ⇒ Array<(DocumentValidationResult, Fixnum, Hash)>
Validate if an MSG file is executable Validate if an input file is an MSG email file; if the document is not valid
532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 |
# File 'lib/cloudmersive-convert-api-client/api/validate_document_api.rb', line 532 def validate_document_msg_validation_with_http_info(input_file, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ValidateDocumentApi.validate_document_msg_validation ...' end # verify the required parameter 'input_file' is set if @api_client.config.client_side_validation && input_file.nil? fail ArgumentError, "Missing the required parameter 'input_file' when calling ValidateDocumentApi.validate_document_msg_validation" end # resource path local_var_path = '/convert/validate/msg' # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json', 'text/json', 'application/xml', 'text/xml']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['multipart/form-data']) # form parameters form_params = {} form_params['inputFile'] = input_file # http body (model) post_body = nil auth_names = ['Apikey'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'DocumentValidationResult') if @api_client.config.debugging @api_client.config.logger.debug "API called: ValidateDocumentApi#validate_document_msg_validation\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#validate_document_pdf_validation(input_file, opts = {}) ⇒ DocumentValidationResult
Validate a PDF document file Validate a PDF document; if the document is not valid, identifies the errors in the document. Also checks if the PDF is password protected.
577 578 579 580 |
# File 'lib/cloudmersive-convert-api-client/api/validate_document_api.rb', line 577 def validate_document_pdf_validation(input_file, opts = {}) data, _status_code, _headers = validate_document_pdf_validation_with_http_info(input_file, opts) data end |
#validate_document_pdf_validation_with_http_info(input_file, opts = {}) ⇒ Array<(DocumentValidationResult, Fixnum, Hash)>
Validate a PDF document file Validate a PDF document; if the document is not valid, identifies the errors in the document. Also checks if the PDF is password protected.
587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 |
# File 'lib/cloudmersive-convert-api-client/api/validate_document_api.rb', line 587 def validate_document_pdf_validation_with_http_info(input_file, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ValidateDocumentApi.validate_document_pdf_validation ...' end # verify the required parameter 'input_file' is set if @api_client.config.client_side_validation && input_file.nil? fail ArgumentError, "Missing the required parameter 'input_file' when calling ValidateDocumentApi.validate_document_pdf_validation" end # resource path local_var_path = '/convert/validate/pdf' # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json', 'text/json', 'application/xml', 'text/xml']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['multipart/form-data']) # form parameters form_params = {} form_params['inputFile'] = input_file # http body (model) post_body = nil auth_names = ['Apikey'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'DocumentValidationResult') if @api_client.config.debugging @api_client.config.logger.debug "API called: ValidateDocumentApi#validate_document_pdf_validation\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#validate_document_pptx_validation(input_file, opts = {}) ⇒ DocumentValidationResult
Validate a PowerPoint presentation (PPTX) Validate a PowerPoint presentation (PPTX); if the document is not valid, identifies the errors in the document
632 633 634 635 |
# File 'lib/cloudmersive-convert-api-client/api/validate_document_api.rb', line 632 def validate_document_pptx_validation(input_file, opts = {}) data, _status_code, _headers = validate_document_pptx_validation_with_http_info(input_file, opts) data end |
#validate_document_pptx_validation_with_http_info(input_file, opts = {}) ⇒ Array<(DocumentValidationResult, Fixnum, Hash)>
Validate a PowerPoint presentation (PPTX) Validate a PowerPoint presentation (PPTX); if the document is not valid, identifies the errors in the document
642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 |
# File 'lib/cloudmersive-convert-api-client/api/validate_document_api.rb', line 642 def validate_document_pptx_validation_with_http_info(input_file, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ValidateDocumentApi.validate_document_pptx_validation ...' end # verify the required parameter 'input_file' is set if @api_client.config.client_side_validation && input_file.nil? fail ArgumentError, "Missing the required parameter 'input_file' when calling ValidateDocumentApi.validate_document_pptx_validation" end # resource path local_var_path = '/convert/validate/pptx' # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json', 'text/json', 'application/xml', 'text/xml']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['multipart/form-data']) # form parameters form_params = {} form_params['inputFile'] = input_file # http body (model) post_body = nil auth_names = ['Apikey'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'DocumentValidationResult') if @api_client.config.debugging @api_client.config.logger.debug "API called: ValidateDocumentApi#validate_document_pptx_validation\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#validate_document_rar_validation(input_file, opts = {}) ⇒ DocumentValidationResult
Validate a RAR Archive file (RAR) Validate a RAR archive file (RAR)
687 688 689 690 |
# File 'lib/cloudmersive-convert-api-client/api/validate_document_api.rb', line 687 def validate_document_rar_validation(input_file, opts = {}) data, _status_code, _headers = validate_document_rar_validation_with_http_info(input_file, opts) data end |
#validate_document_rar_validation_with_http_info(input_file, opts = {}) ⇒ Array<(DocumentValidationResult, Fixnum, Hash)>
Validate a RAR Archive file (RAR) Validate a RAR archive file (RAR)
697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 |
# File 'lib/cloudmersive-convert-api-client/api/validate_document_api.rb', line 697 def validate_document_rar_validation_with_http_info(input_file, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ValidateDocumentApi.validate_document_rar_validation ...' end # verify the required parameter 'input_file' is set if @api_client.config.client_side_validation && input_file.nil? fail ArgumentError, "Missing the required parameter 'input_file' when calling ValidateDocumentApi.validate_document_rar_validation" end # resource path local_var_path = '/convert/validate/rar' # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json', 'text/json', 'application/xml', 'text/xml']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['multipart/form-data']) # form parameters form_params = {} form_params['inputFile'] = input_file # http body (model) post_body = nil auth_names = ['Apikey'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'DocumentValidationResult') if @api_client.config.debugging @api_client.config.logger.debug "API called: ValidateDocumentApi#validate_document_rar_validation\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#validate_document_tar_validation(input_file, opts = {}) ⇒ DocumentValidationResult
Validate a TAR Tarball Archive file (TAR) Validate a TAR tarball archive file (TAR)
742 743 744 745 |
# File 'lib/cloudmersive-convert-api-client/api/validate_document_api.rb', line 742 def validate_document_tar_validation(input_file, opts = {}) data, _status_code, _headers = validate_document_tar_validation_with_http_info(input_file, opts) data end |
#validate_document_tar_validation_with_http_info(input_file, opts = {}) ⇒ Array<(DocumentValidationResult, Fixnum, Hash)>
Validate a TAR Tarball Archive file (TAR) Validate a TAR tarball archive file (TAR)
752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 |
# File 'lib/cloudmersive-convert-api-client/api/validate_document_api.rb', line 752 def validate_document_tar_validation_with_http_info(input_file, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ValidateDocumentApi.validate_document_tar_validation ...' end # verify the required parameter 'input_file' is set if @api_client.config.client_side_validation && input_file.nil? fail ArgumentError, "Missing the required parameter 'input_file' when calling ValidateDocumentApi.validate_document_tar_validation" end # resource path local_var_path = '/convert/validate/tar' # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json', 'text/json', 'application/xml', 'text/xml']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['multipart/form-data']) # form parameters form_params = {} form_params['inputFile'] = input_file # http body (model) post_body = nil auth_names = ['Apikey'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'DocumentValidationResult') if @api_client.config.debugging @api_client.config.logger.debug "API called: ValidateDocumentApi#validate_document_tar_validation\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#validate_document_xlsx_validation(input_file, opts = {}) ⇒ DocumentValidationResult
Validate a Excel document (XLSX) Validate a Excel document (XLSX); if the document is not valid, identifies the errors in the document
797 798 799 800 |
# File 'lib/cloudmersive-convert-api-client/api/validate_document_api.rb', line 797 def validate_document_xlsx_validation(input_file, opts = {}) data, _status_code, _headers = validate_document_xlsx_validation_with_http_info(input_file, opts) data end |
#validate_document_xlsx_validation_with_http_info(input_file, opts = {}) ⇒ Array<(DocumentValidationResult, Fixnum, Hash)>
Validate a Excel document (XLSX) Validate a Excel document (XLSX); if the document is not valid, identifies the errors in the document
807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 |
# File 'lib/cloudmersive-convert-api-client/api/validate_document_api.rb', line 807 def validate_document_xlsx_validation_with_http_info(input_file, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ValidateDocumentApi.validate_document_xlsx_validation ...' end # verify the required parameter 'input_file' is set if @api_client.config.client_side_validation && input_file.nil? fail ArgumentError, "Missing the required parameter 'input_file' when calling ValidateDocumentApi.validate_document_xlsx_validation" end # resource path local_var_path = '/convert/validate/xlsx' # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json', 'text/json', 'application/xml', 'text/xml']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['multipart/form-data']) # form parameters form_params = {} form_params['inputFile'] = input_file # http body (model) post_body = nil auth_names = ['Apikey'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'DocumentValidationResult') if @api_client.config.debugging @api_client.config.logger.debug "API called: ValidateDocumentApi#validate_document_xlsx_validation\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#validate_document_xml_validation(input_file, opts = {}) ⇒ DocumentValidationResult
Validate an XML file Validate an XML document file; if the document is not valid, identifies the errors in the document
852 853 854 855 |
# File 'lib/cloudmersive-convert-api-client/api/validate_document_api.rb', line 852 def validate_document_xml_validation(input_file, opts = {}) data, _status_code, _headers = validate_document_xml_validation_with_http_info(input_file, opts) data end |
#validate_document_xml_validation_with_http_info(input_file, opts = {}) ⇒ Array<(DocumentValidationResult, Fixnum, Hash)>
Validate an XML file Validate an XML document file; if the document is not valid, identifies the errors in the document
862 863 864 865 866 867 868 869 870 871 872 873 874 875 876 877 878 879 880 881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 |
# File 'lib/cloudmersive-convert-api-client/api/validate_document_api.rb', line 862 def validate_document_xml_validation_with_http_info(input_file, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ValidateDocumentApi.validate_document_xml_validation ...' end # verify the required parameter 'input_file' is set if @api_client.config.client_side_validation && input_file.nil? fail ArgumentError, "Missing the required parameter 'input_file' when calling ValidateDocumentApi.validate_document_xml_validation" end # resource path local_var_path = '/convert/validate/xml' # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json', 'text/json', 'application/xml', 'text/xml']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['multipart/form-data']) # form parameters form_params = {} form_params['inputFile'] = input_file # http body (model) post_body = nil auth_names = ['Apikey'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'DocumentValidationResult') if @api_client.config.debugging @api_client.config.logger.debug "API called: ValidateDocumentApi#validate_document_xml_validation\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#validate_document_zip_validation(input_file, opts = {}) ⇒ DocumentValidationResult
Validate a Zip Archive file (zip) Validate a Zip archive file (ZIP)
907 908 909 910 |
# File 'lib/cloudmersive-convert-api-client/api/validate_document_api.rb', line 907 def validate_document_zip_validation(input_file, opts = {}) data, _status_code, _headers = validate_document_zip_validation_with_http_info(input_file, opts) data end |
#validate_document_zip_validation_with_http_info(input_file, opts = {}) ⇒ Array<(DocumentValidationResult, Fixnum, Hash)>
Validate a Zip Archive file (zip) Validate a Zip archive file (ZIP)
917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 938 939 940 941 942 943 944 945 946 947 948 949 950 951 952 953 954 955 956 |
# File 'lib/cloudmersive-convert-api-client/api/validate_document_api.rb', line 917 def validate_document_zip_validation_with_http_info(input_file, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ValidateDocumentApi.validate_document_zip_validation ...' end # verify the required parameter 'input_file' is set if @api_client.config.client_side_validation && input_file.nil? fail ArgumentError, "Missing the required parameter 'input_file' when calling ValidateDocumentApi.validate_document_zip_validation" end # resource path local_var_path = '/convert/validate/zip' # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json', 'text/json', 'application/xml', 'text/xml']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['multipart/form-data']) # form parameters form_params = {} form_params['inputFile'] = input_file # http body (model) post_body = nil auth_names = ['Apikey'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'DocumentValidationResult') if @api_client.config.debugging @api_client.config.logger.debug "API called: ValidateDocumentApi#validate_document_zip_validation\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |