Method: CloudmersiveConvertApiClient::EditDocumentApi#edit_document_docx_get_comments
- Defined in:
- lib/cloudmersive-convert-api-client/api/edit_document_api.rb
#edit_document_docx_get_comments(req_config, opts = {}) ⇒ GetDocxCommentsResponse
Get comments from a Word DOCX document as a flat list Returns the comments and review annotations stored in the Word Document (DOCX) format file as a flattened list (not as a hierarchy of comments and replies).
571 572 573 574 |
# File 'lib/cloudmersive-convert-api-client/api/edit_document_api.rb', line 571 def edit_document_docx_get_comments(req_config, opts = {}) data, _status_code, _headers = edit_document_docx_get_comments_with_http_info(req_config, opts) data end |